@@ -36,10 +36,10 @@
 
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
-
 ;;}}}
 ;;{{{ Customizations:
-
+;;; forward decl:
+(defvar emacspeak-speak-messages)
 ;;}}}
 ;;{{{ Definitions
 
@@ -73,8 +73,9 @@
 
 (defun amixer-populate-settings (control)
   "Populate control with its settings information."
-  (declare (special amixer-card amixer-device))
+  (cl-declare (special amixer-card amixer-device))
   (let ((fields nil)
+        (emacspeak-speak-messages nil)
         (slots nil)
         (current nil))
     (with-temp-buffer
@@ -94,12 +95,12 @@
       (setq slots
             (cl-loop for f in fields
                      collect
-                     (second (split-string f "="))))
+                     (cl-second (split-string f "="))))
       (while (and (not (eobp))
                   (looking-at "^ *;"))
         (forward-line 1))
       (setq current
-            (second
+            (cl-second
              (split-string
               (buffer-substring-no-properties
                (line-beginning-position)
@@ -118,11 +119,14 @@
 
 (defun amixer-build-db ()
   "Create a database of amixer controls and their settings."
-  (declare (special amixer-db amixer-device amixer-program))
-  (unless amixer-program (error "You dont have a standard amixer."))m
-  (let ((controls nil)
+  (cl-declare (special amixer-db amixer-device amixer-program))
+  (unless amixer-program (error "You dont have a standard amixer."))
+  (let (
+        (message-log-max nil)
+        (controls nil)
         (fields nil)
-        (slots nil))
+        (slots nil)
+        (emacspeak-speak-messages nil))
     (with-temp-buffer
       (shell-command
        (format
@@ -146,14 +150,14 @@
         (setq slots
               (cl-loop for f in fields
                        collect
-                       (second (split-string f "="))))
+                       (cl-second (split-string f "="))))
         (push
          (cons
-          (third slots)
+          (cl-third slots)
           (make-amixer-control
-           :numid (first slots)
-           :iface (second slots)
-           :name (third slots)))
+           :numid (cl-first slots)
+           :iface (cl-second slots)
+           :name (cl-third slots)))
          controls)
         (forward-line 1))               ; done collecting controls
       (mapc #'amixer-populate-settings controls)
@@ -164,8 +168,9 @@
 
 (defun amixer-get-enumerated-values(control)
   "Return list of enumerated values."
-  (declare (special amixer-device))
-  (let ((values nil))
+  (cl-declare (special amixer-device))
+  (let ((values nil)
+        (emacspeak-speak-messages nil))
     (with-temp-buffer
       (shell-command
        (format
@@ -185,6 +190,8 @@
            values))
         (forward-line 1))
       (nreverse values))))
+
+;;;###autoload
 (defvar amixer-alsactl-config-file
   nil
   "Personal sound card settings. Copied from /var/lib/alsa/asound.state
@@ -194,7 +201,7 @@ use."
 
 (defun amixer-alsactl-setup ()
   "Set up alsactl sound state."
-  (declare (special amixer-alsactl-config-file))
+  (cl-declare (special amixer-alsactl-config-file))
   (setq
    amixer-alsactl-config-file
    (let ((sys-alsa "/var/lib/alsa/asound.state")
@@ -206,7 +213,7 @@ use."
 ;;;###autoload
 (defun amixer-restore (&optional conf-file)
   "Restore alsa settings."
-  (declare (special alsactl-program))
+  (cl-declare (special alsactl-program))
   (if conf-file
       (start-process
        "AlsaCtl" nil alsactl-program
@@ -224,7 +231,7 @@ use."
   "Interactively manipulate ALSA settings.
 Interactive prefix arg refreshes cache."
   (interactive "P")
-  (declare (special amixer-db amixer-alsactl-config-file amixer-program))
+  (cl-declare (special amixer-db amixer-alsactl-config-file amixer-program))
   (unless amixer-alsactl-config-file (amixer-alsactl-setup))
   (when (or refresh (null amixer-db))
     (amixer-build-db))
@@ -275,16 +282,17 @@ Interactive prefix arg refreshes cache."
 (defun amixer-equalize()
   "Set equalizer. Only affects device `equal'."
   (interactive)
-  (declare (special amixer-device))
-  (let ((amixer-device "equal"))
+  (cl-declare (special amixer-device))
+  (let ((amixer-device "equal")
+        (emacspeak-speak-messages nil))
     (amixer 'refresh)
-    ;;; mark db dirty.
+;;; mark db dirty.
     (setq amixer-db nil)))
 
 (defun amixer-reset-equalizer ()
   "Reset equalizer to default values -- 66% for all 10 bands."
   (interactive)
-  (declare (special amixer-program))
+  (cl-declare (special amixer-program))
   (cl-loop
    for  i from 1 to 10 do
    (start-process
@@ -292,20 +300,20 @@ Interactive prefix arg refreshes cache."
     "-Dequal"
     "cset"
     (format "numid=%s" i)
-    "66,66" ))
+    "66,66"))
   (message "Reset equalizer"))
 
 ;;;###autoload
 (defun amixer-store()
   "Persist current amixer settings."
   (interactive)
-  (declare (special  amixer-alsactl-config-file alsactl-program))
+  (cl-declare (special  amixer-alsactl-config-file alsactl-program))
   (unless amixer-alsactl-config-file (amixer-alsactl-setup))
   (when amixer-alsactl-config-file
     (start-process
      "AlsaCtl" nil alsactl-program
      "-f"amixer-alsactl-config-file
-     "store" )
+     "store")
     (emacspeak-auditory-icon 'task-done)
     (message "Persisted amixer state.")))
 ;;}}}
@@ -314,7 +322,7 @@ Interactive prefix arg refreshes cache."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
