@@ -48,8 +48,8 @@
 ;;{{{ required modules
 
 ;;; Code:
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'acss-structure)
 (require 'tts)
 
@@ -64,7 +64,7 @@
            (set-default sym val)
            (when (and (getenv "DTK_PROGRAM")
                       (string-match "dtk" (getenv "DTK_PROGRAM")))
-           (setq-default dtk-speech-rate val))))
+             (setq-default dtk-speech-rate val))))
 
 ;;}}}
 ;;{{{  Top-level TTS  switcher
@@ -103,12 +103,12 @@ The string can set any Dectalk parameter.")
   "Define a Dectalk voice named NAME.
 This voice will be set   by sending the string
 COMMAND-STRING to the Dectalk."
-  (declare (special dectalk-voice-table))
+  (cl-declare (special dectalk-voice-table))
   (puthash  name command-string  dectalk-voice-table))
 
 (defun dectalk-get-voice-command (name)
   "Retrieve command string for  voice NAME."
-  (declare (special dectalk-voice-table))
+  (cl-declare (special dectalk-voice-table))
   (cond
    ((listp name)
     (mapconcat #'dectalk-get-voice-command name " "))
@@ -117,7 +117,7 @@ COMMAND-STRING to the Dectalk."
 
 (defun dectalk-voice-defined-p (name)
   "Check if there is a voice named NAME defined."
-  (declare (special dectalk-voice-table))
+  (cl-declare (special dectalk-voice-table))
   (gethash name dectalk-voice-table))
 
 ;;}}}
@@ -150,7 +150,7 @@ COMMAND-STRING to the Dectalk."
 
 (defun dectalk-set-family-code (name code)
   "Set control code for voice family NAME  to CODE."
-  (declare (special dectalk-family-table))
+  (cl-declare (special dectalk-family-table))
   (when (stringp name)
     (setq name (intern name)))
   (setq dectalk-family-table
@@ -159,7 +159,7 @@ COMMAND-STRING to the Dectalk."
 
 (defun dectalk-get-family-code (name)
   "Get control code for voice family NAME."
-  (declare (special dectalk-family-table))
+  (cl-declare (special dectalk-family-table))
   (when (stringp name)
     (setq name (intern name)))
   (or (cadr (assq  name dectalk-family-table))
@@ -187,13 +187,13 @@ Values are vectors holding the control codes for the 10 settings.")
   "Set up voice FAMILY.
 Argument DIMENSION is the dimension being set,
 and TABLE gives the values along that dimension."
-  (declare (special dectalk-css-code-tables))
+  (cl-declare (special dectalk-css-code-tables))
   (let ((key (intern (format "%s-%s" family dimension))))
     (puthash  key table dectalk-css-code-tables)))
 
 (defun dectalk-css-get-code-table (family dimension)
   "Retrieve table of values for specified FAMILY and DIMENSION."
-  (declare (special dectalk-css-code-tables))
+  (cl-declare (special dectalk-css-code-tables))
   (let ((key (intern (format "%s-%s" family dimension))))
     (gethash key dectalk-css-code-tables)))
 
@@ -217,14 +217,13 @@ and TABLE gives the values along that dimension."
 ;;{{{  paul average pitch
 
 (let ((table (make-vector 10 "")))
-  (mapcar
-   (function
-    (lambda (setting)
+  (mapc
+   #'(lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format " ap %s hs % s"
-                    (second setting)
-                    (third setting)))))
+                    (cl-second setting)
+                    (cl-third setting))))
    '(
      (0 96 115)
      (1 101 112)
@@ -244,14 +243,13 @@ and TABLE gives the values along that dimension."
 ;;; Harry  has a big head --and a lower pitch for the middle setting
 
 (let ((table (make-vector 10 "")))
-  (mapcar
-   (function
-    (lambda (setting)
+  (mapc
+   #'(lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format " ap %s hs % s"
-                    (second setting)
-                    (third setting)))))
+                    (cl-second setting)
+                    (cl-third setting))))
    '(
      (0 50 125)
      (1 59 123)
@@ -270,14 +268,13 @@ and TABLE gives the values along that dimension."
 ;;{{{  betty average pitch
 
 (let ((table (make-vector 10 "")))
-  (mapcar
-   (function
-    (lambda (setting)
+  (mapc
+   #'(lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format " ap %s hs % s"
-                    (second setting)
-                    (third setting)))))
+                    (cl-second setting)
+                    (cl-third setting))))
    '(
      (0 160 115)
      (1 170 112)
@@ -314,14 +311,13 @@ and TABLE gives the values along that dimension."
 ;;{{{  paul pitch range
 
 (let ((table (make-vector 10 "")))
-  (mapcar
-   (function
-    (lambda (setting)
+  (mapc
+   #'(lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format " pr %s as %s "
-                    (second setting)
-                    (third setting)))))
+                    (cl-second setting)
+                    (cl-third setting))))
    '(
      (0 0 0)
      (1 20 10)
@@ -340,14 +336,13 @@ and TABLE gives the values along that dimension."
 ;;{{{  harry pitch range
 
 (let ((table (make-vector 10 "")))
-  (mapcar
-   (function
-    (lambda (setting)
+  (mapc
+   #'(lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format " pr %s as %s "
-                    (second setting)
-                    (third setting)))))
+                    (cl-second setting)
+                    (cl-third setting))))
    '(
      (0 0 0)
      (1 16 20)
@@ -366,14 +361,13 @@ and TABLE gives the values along that dimension."
 ;;{{{  betty pitch range
 
 (let ((table (make-vector 10 "")))
-  (mapcar
-   (function
-    (lambda (setting)
+  (mapc
+   #'(lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format " pr %s as %s "
-                    (second setting)
-                    (third setting)))))
+                    (cl-second setting)
+                    (cl-third setting))))
    '(
      (0 0 0)
      (1 50 10)
@@ -412,16 +406,15 @@ and TABLE gives the values along that dimension."
 ;;{{{  paul stress
 
 (let ((table (make-vector 10 "")))
-  (mapcar
-   (function
-    (lambda (setting)
+  (mapc
+   #'(lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format " hr %s sr %s qu %s bf %s "
-                    (second setting)
-                    (third setting)
-                    (fourth setting)
-                    (fifth setting)))))
+                    (cl-second setting)
+                    (cl-third setting)
+                    (cl-fourth setting)
+                    (cl-fifth setting))))
    '(
      (0  0 0 0 0)
      (1 3 6  20 3)
@@ -440,16 +433,15 @@ and TABLE gives the values along that dimension."
 ;;{{{  harry stress
 
 (let ((table (make-vector 10 "")))
-  (mapcar
-   (function
-    (lambda (setting)
+  (mapc
+   #'(lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format " hr %s sr %s qu %s bf %s "
-                    (second setting)
-                    (third setting)
-                    (fourth setting)
-                    (fifth setting)))))
+                    (cl-second setting)
+                    (cl-third setting)
+                    (cl-fourth setting)
+                    (cl-fifth setting))))
    '(
      (0  0 0 0 0)
      (1 4 6 2 2)
@@ -468,16 +460,15 @@ and TABLE gives the values along that dimension."
 ;;{{{  betty stress
 
 (let ((table (make-vector 10 "")))
-  (mapcar
-   (function
-    (lambda (setting)
+  (mapc
+   #'(lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format " hr %s sr %s qu %s bf %s "
-                    (second setting)
-                    (third setting)
-                    (fourth setting)
-                    (fifth setting)))))
+                    (cl-second setting)
+                    (cl-third setting)
+                    (cl-fourth setting)
+                    (cl-fifth setting))))
    '(
      (0  1 1 0 0)
      (1 3 4 11 0)
@@ -509,13 +500,12 @@ and TABLE gives the values along that dimension."
 ;;{{{  paul richness
 
 (let ((table (make-vector 10 "")))
-  (mapcar
-   (function
-    (lambda (setting)
-      (aset table (first setting)
+  (mapc
+   #'(lambda (setting)
+      (aset table (cl-first setting)
             (format " ri %s sm %s "
-                    (second setting)
-                    (third setting)))))
+                    (cl-second setting)
+                    (cl-third setting))))
    '(
      (0 0 100)
      (1 14 80)
@@ -534,13 +524,12 @@ and TABLE gives the values along that dimension."
 ;;{{{  harry richness
 
 (let ((table (make-vector 10 "")))
-  (mapcar
-   (function
-    (lambda (setting)
-      (aset table (first setting)
+  (mapc
+   #'(lambda (setting)
+      (aset table (cl-first setting)
             (format " ri %s sm %s "
-                    (second setting)
-                    (third setting)))))
+                    (cl-second setting)
+                    (cl-third setting))))
    '(
      (0 100 0)
      (1 96 3)
@@ -559,13 +548,12 @@ and TABLE gives the values along that dimension."
 ;;{{{  betty richness
 
 (let ((table (make-vector 10 "")))
-  (mapcar
-   (function
-    (lambda (setting)
-      (aset table (first setting)
+  (mapc
+   #'(lambda (setting)
+      (aset table (cl-first setting)
             (format " ri %s sm %s "
-                    (second setting)
-                    (third setting)))))
+                    (cl-second setting)
+                    (cl-third setting))))
    '(
      (0 0 100)
      (1 8 76)
@@ -627,16 +615,16 @@ and TABLE gives the values along that dimension."
 
 (defun dectalk-list-voices ()
   "List defined voices."
-  (declare (special dectalk-voice-table))
+  (cl-declare (special dectalk-voice-table))
   (cl-loop for k being the hash-keys of dectalk-voice-table
-        collect   k))
+           collect   k))
 
 ;;}}}
 ;;{{{ configurater
 ;;;###autoload
 (defun dectalk-configure-tts ()
   "Configures TTS environment to use Dectalk family of synthesizers."
-  (declare (special  dectalk-default-speech-rate
+  (cl-declare (special  dectalk-default-speech-rate
                      tts-default-speech-rate tts-default-voice))
   (setq tts-default-voice 'paul)
   (fset 'tts-list-voices 'dectalk-list-voices)
@@ -657,7 +645,7 @@ and TABLE gives the values along that dimension."
 ;;;###autoload
 (defun dectalk-make-tts-env  ()
   "Constructs a TTS environment for Dectalk."
-  (declare (special dectalk-default-speech-rate))
+  (cl-declare (special dectalk-default-speech-rate))
   (make-tts-env
    :name :dectalk
    :default-voice 'paul
@@ -676,7 +664,7 @@ and TABLE gives the values along that dimension."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
