@@ -64,8 +64,8 @@
 ;;}}}
 ;;{{{  Required modules
 
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'button)
 (require 'emacspeak-webutils)
@@ -85,15 +85,15 @@
 (defun emacspeak-bbc-read-schedules-url ()
   "Return URL for schedule for specified station, outlet, date.
 Date defaults to today."
-  (declare  (special emacspeak-bbc-json-schedules-template
+  (cl-declare  (special emacspeak-bbc-json-schedules-template
                      emacspeak-bbc-station-list))
   (let* ((fields (split-string
                   (completing-read "Station:Outlet:" emacspeak-bbc-station-list
                                    nil 'must-match)
                   ":"))
          (date (emacspeak-speak-read-date-year/month/date))
-         (station (first fields))
-         (outlet (second fields)))
+         (station (cl-first fields))
+         (outlet (cl-second fields)))
     (format emacspeak-bbc-json-schedules-template
             station
             (if  (null outlet) "" (format "%s/" outlet))
@@ -105,7 +105,7 @@ Date defaults to today."
 
 (defun emacspeak-bbc-read-genre-url ()
   "Return URL for specified  genre."
-  (declare (special emacspeak-bbc-json-genre-template))
+  (cl-declare (special emacspeak-bbc-json-genre-template))
   (let ((genre (read-from-minibuffer "Genre/Genre/Genre:")))
     (format emacspeak-bbc-json-genre-template genre)))
 
@@ -209,7 +209,7 @@ Date defaults to today."
 
 (defun emacspeak-bbc-get-iplayer-action (button)
   "Stream using get_iplayer."
-  (declare (special emacspeak-bbc-get-iplayer emacspeak-bbc-iplayer-handle))
+  (cl-declare (special emacspeak-bbc-get-iplayer emacspeak-bbc-iplayer-handle))
   (let
       ((command
         (format
@@ -226,7 +226,7 @@ Date defaults to today."
 (defun emacspeak-bbc-get-iplayer-stream-url (url)
   "Stream using get_iplayer."
   (interactive "sURL: ")
-  (declare (special emacspeak-bbc-get-iplayer emacspeak-bbc-iplayer-handle))
+  (cl-declare (special emacspeak-bbc-get-iplayer emacspeak-bbc-iplayer-handle))
   (let
       ((command
         (format
@@ -243,7 +243,7 @@ Date defaults to today."
 (defun emacspeak-bbc-get-iplayer-stream-pid (pid)
   "Stream using get_iplayer."
   (interactive "sURL: ")
-  (declare (special emacspeak-bbc-get-iplayer emacspeak-bbc-iplayer-handle))
+  (cl-declare (special emacspeak-bbc-get-iplayer emacspeak-bbc-iplayer-handle))
   (let
       ((command
         (format
@@ -279,10 +279,10 @@ chrome: Hand off URL to Chrome."
 (defun emacspeak-bbc-iplayer-button-action (button)
   "Generic button action that dispatches to get_iplayer or chrome based
 on user preference."
-  (declare (special emacspeak-bbc-button-action))
+  (cl-declare (special emacspeak-bbc-button-action))
   (ecase emacspeak-bbc-button-action
-    ('chrome (funcall #'emacspeak-bbc-chrome-action button))
-    ('get-iplayer (funcall #'emacspeak-bbc-get-iplayer-action button))))
+         ('chrome (funcall #'emacspeak-bbc-chrome-action button))
+         ('get-iplayer (funcall #'emacspeak-bbc-get-iplayer-action button))))
 
 ;;}}}
 ;;{{{ BBC IPlayer Interaction
@@ -316,7 +316,7 @@ Interactive prefix arg filters  content by genre."
 
 (defun emacspeak-bbc-iplayer-create (json &optional genres)
   "Create iplayer buffer given JSON object."
-  (declare (special emacspeak-bbc-json))
+  (cl-declare (special emacspeak-bbc-json))
   (let* ((inhibit-read-only t)
          (title (or
                  (g-json-lookup "schedule.service.title" json)
@@ -355,7 +355,7 @@ Interactive prefix arg filters  content by genre."
 
 (defun   emacspeak-bbc-insert-show (show)
   "Insert a formatted button for this show."
-  (declare (special emacspeak-bbc-iplayer-uri-prefix))
+  (cl-declare (special emacspeak-bbc-iplayer-uri-prefix))
   (let ((title  (g-json-lookup-string "programme.display_titles.title" show))
         (pid (g-json-lookup-string "programme.pid" show))
         (short-title
@@ -379,7 +379,7 @@ Interactive prefix arg filters  content by genre."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
