@@ -40,6 +40,7 @@
 
 ;;{{{ required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'bs)
 ;;}}}
@@ -57,7 +58,7 @@
 (defun emacspeak-bs-speak-buffer-line ()
   "Speak information about this buffer"
   (interactive)
-  (declare (special dtk-stop-immediately
+  (cl-declare (special dtk-stop-immediately
                     list-buffers-directory))
   (unless (eq major-mode 'bs-mode)
     (error "This command can only be used in buffer menus"))
@@ -247,7 +248,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
