@@ -8,7 +8,7 @@
 (put 'cd-tool 'custom-loads '(cd-tool))
 (put 'dtk 'custom-loads '(dtk-speak))
 (put 'dtk-unicode 'custom-loads '(dtk-unicode))
-(put 'emacspeak 'custom-loads '(dtk-speak dtk-unicode emacspeak emacspeak-add-log emacspeak-advice emacspeak-aumix emacspeak-bookshare emacspeak-dismal emacspeak-epub emacspeak-erc emacspeak-eshell emacspeak-eterm emacspeak-eudc emacspeak-feeds emacspeak-flyspell emacspeak-forms emacspeak-gnus emacspeak-ido emacspeak-ispell emacspeak-jss emacspeak-keymap emacspeak-kite emacspeak-m-player emacspeak-maths emacspeak-message emacspeak-midge emacspeak-npr emacspeak-nxml emacspeak-ocr emacspeak-pronounce emacspeak-replace emacspeak-setup emacspeak-sounds emacspeak-speak emacspeak-speedbar emacspeak-vm emacspeak-w3 emacspeak-w3m emacspeak-we emacspeak-websearch emacspeak-widget emacspeak-wizards emacspeak-xml-shell emacspeak-xslt sox voice-setup xbacklight))
+(put 'emacspeak 'custom-loads '(dtk-speak dtk-unicode emacspeak emacspeak-add-log emacspeak-advice emacspeak-aumix emacspeak-bookshare emacspeak-dismal emacspeak-epub emacspeak-erc emacspeak-eshell emacspeak-eterm emacspeak-eudc emacspeak-feeds emacspeak-flyspell emacspeak-forms emacspeak-gnus emacspeak-ido emacspeak-ispell emacspeak-jss emacspeak-keymap emacspeak-kite emacspeak-m-player emacspeak-maths emacspeak-message emacspeak-midge emacspeak-npr emacspeak-nxml emacspeak-ocr emacspeak-pronounce emacspeak-setup emacspeak-sounds emacspeak-speak emacspeak-speedbar emacspeak-vm emacspeak-w3 emacspeak-we emacspeak-websearch emacspeak-widget emacspeak-wizards emacspeak-xml-shell emacspeak-xslt sox voice-setup xbacklight))
 (put 'emacspeak-advice 'custom-loads '(emacspeak-advice))
 (put 'emacspeak-aumix 'custom-loads '(emacspeak-aumix))
 (put 'emacspeak-bbc 'custom-loads '(emacspeak-bbc))
@@ -30,6 +30,7 @@
 (put 'emacspeak-gnus 'custom-loads '(emacspeak-gnus))
 (put 'emacspeak-google 'custom-loads '(emacspeak-google))
 (put 'emacspeak-hide 'custom-loads '(emacspeak-hide))
+(put 'emacspeak-ido 'custom-loads '(emacspeak-ido))
 (put 'emacspeak-info 'custom-loads '(emacspeak-info))
 (put 'emacspeak-ispell 'custom-loads '(emacspeak-ispell))
 (put 'emacspeak-jabber 'custom-loads '(emacspeak-jabber))
@@ -52,7 +53,6 @@
 (put 'emacspeak-speedbar 'custom-loads '(emacspeak-speedbar))
 (put 'emacspeak-vm 'custom-loads '(emacspeak-vm))
 (put 'emacspeak-w3 'custom-loads '(emacspeak-w3))
-(put 'emacspeak-w3m 'custom-loads '(emacspeak-w3m))
 (put 'emacspeak-we 'custom-loads '(emacspeak-we))
 (put 'emacspeak-websearch 'custom-loads '(emacspeak-websearch))
 (put 'emacspeak-webspace 'custom-loads '(emacspeak-webspace))
@@ -67,19 +67,18 @@
 (put 'forms 'custom-loads '(emacspeak-forms))
 (put 'games 'custom-loads '(tetris))
 (put 'gnus 'custom-loads '(emacspeak-gnus))
-(put 'isearch 'custom-loads '(emacspeak-replace))
+(put 'isearch 'custom-loads '(emacspeak-advice))
 (put 'message 'custom-loads '(emacspeak-message))
 (put 'soundscape 'custom-loads '(soundscape))
 (put 'sox 'custom-loads '(sox sox-gen))
 (put 'sox-gen 'custom-loads '(sox-gen))
 (put 'speedbar 'custom-loads '(emacspeak-speedbar))
 (put 'tetris 'custom-loads '(tetris))
-(put 'tts 'custom-loads '(dectalk-voices dtk-speak espeak-voices mac-voices outloud-voices))
+(put 'tts 'custom-loads '(dectalk-voices dtk-speak emacspeak-setup espeak-voices mac-voices outloud-voices))
 (put 'vm 'custom-loads '(emacspeak-vm))
 (put 'voice-fonts 'custom-loads '(voice-setup))
 (put 'voice-lock 'custom-loads '(voice-setup))
 (put 'w3 'custom-loads '(emacspeak-w3))
-(put 'w3m 'custom-loads '(emacspeak-w3m))
 (put 'widget 'custom-loads '(emacspeak-widget))
 (put 'xbacklight 'custom-loads '(xbacklight))
 
