@@ -43,6 +43,7 @@
 ;;; Code:
 ;;}}}
 ;;{{{ required modules
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 
 ;;}}}
@@ -55,7 +56,7 @@
   "Map base fonts to voices.
 Useful in voiceifying rich text."
   (interactive "r")
-  (declare (special emacspeak-enriched-font-faces-to-voiceify))
+  (cl-declare (special emacspeak-enriched-font-faces-to-voiceify))
   (set (make-local-variable 'voice-lock-mode) t)
   (with-silent-modifications
     (save-excursion
@@ -98,7 +99,7 @@ Useful in voiceifying rich text."
           (when (listp face)
             (setq face 
                   (cl-loop for f in emacspeak-enriched-font-faces-to-voiceify
-                        thereis (find f face))))
+                           thereis (find f face))))
           (when face 
             (put-text-property start  (point)
                                'personality
@@ -135,7 +136,7 @@ Useful in voiceifying rich text."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
