@@ -49,6 +49,7 @@
 ;;}}}
 ;;{{{  Required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{ doctar
@@ -56,8 +57,8 @@
 (defadvice doctor-txtype (after emacspeak pre act)
   (dtk-speak
    (mapconcat
-    (function (lambda (s)
-                (format "%s" s)))
+    #'(lambda (s)
+                (format "%s" s))
     (ad-get-arg 0)
     " ")))
 
@@ -88,14 +89,14 @@
 (defun emacspeak-hangman-speak-statistics ()
   "Speak statistics."
   (interactive)
-  (declare (special hm-win-statistics))
+  (cl-declare (special hm-win-statistics))
   (message "         Games won: %d    Games Lost: %d"
            (aref hm-win-statistics 0)
            (aref hm-win-statistics 1)))
 
 (defun emacspeak-hangman-setup-pronunciations ()
   "Setup pronunciation dictionaries."
-  (declare (special emacspeak-pronounce-pronunciation-table))
+  (cl-declare (special emacspeak-pronounce-pronunciation-table))
   (emacspeak-pronounce-add-dictionary-entry 'hm-mode "_" ".")
   (when (or (not (boundp 'emacspeak-pronounce-pronunciation-table))
             (not emacspeak-pronounce-pronunciation-table))
@@ -109,14 +110,14 @@
 (defun emacspeak-hangman-speak-guess ()
   "Speak current guessed string. "
   (interactive)
-  (declare (special hm-current-guess-string
+  (cl-declare (special hm-current-guess-string
                     hm-current-word))
   (let ((string (make-string  (length hm-current-word)
                               ?\))))
     (cl-loop for i from 0 to (1- (length hm-current-word))
-          do
-          (aset  string  i
-                 (aref hm-current-guess-string (* i 2))))
+             do
+             (aset  string  i
+                    (aref hm-current-guess-string (* i 2))))
     (message  "%s:  %s "
               (length string)
               (downcase string))))
@@ -126,9 +127,9 @@
   (when (ems-interactive-p)
     (emacspeak-hangman-setup-pronunciations)
     (emacspeak-auditory-icon 'open-object)))
-(declaim (special hm-map))
+(cl-declaim (special hm-map))
 (when (boundp 'hm-map)
-  (declaim (special hm-map))
+  (cl-declaim (special hm-map))
   (define-key hm-map " " 'emacspeak-hangman-speak-guess)
   (define-key hm-map "=" 'emacspeak-hangman-speak-statistics)
   )
@@ -139,7 +140,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
