@@ -49,7 +49,14 @@
 
 ;;; Code:
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
+;;}}}
+;;{{{ Forward decls:
+(declare-function eperiodic-get-element-property  (e prop) "eperiodic.el")
+(declare-function eperiodic-element-at (&optional pos) "eperiodic.el")
+
+
 ;;}}}
 ;;{{{ faces and voices 
 (voice-setup-add-map
@@ -73,7 +80,7 @@
 
 (defun emacspeak-eperiodic-name-element-at-point ()
   "Returns name of current element."
-  (declare (special eperiodic-element-properties))
+  (cl-declare (special eperiodic-element-properties))
   (let ((name 
          (cdr
           (assoc 'name
@@ -117,7 +124,7 @@
   (forward-line 2)
   (emacspeak-speak-line)
   (emacspeak-auditory-icon 'large-movement))
-(declaim (special eperiodic-mode-map))
+(cl-declaim (special eperiodic-mode-map))
 (when (boundp 'eperiodic-mode-map)
   (define-key eperiodic-mode-map " " 'emacspeak-eperiodic-speak-current-element)
   (define-key  eperiodic-mode-map "x" 'emacspeak-eperiodic-goto-property-section)
@@ -137,7 +144,7 @@
 (defun emacspeak-eperiodic-play-description ()
   "Play audio description from WebElements."
   (interactive)
-  (declare (special emacspeak-eperiodic-media-location))
+  (cl-declare (special emacspeak-eperiodic-media-location))
   (let ((e (eperiodic-element-at)))
     (unless e  (error "No element under point."))
     (funcall emacspeak-media-player 
@@ -204,7 +211,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
