@@ -50,6 +50,7 @@
 ;;}}}
 ;;{{{ required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'esh-arg)
 
@@ -59,7 +60,7 @@
 ;;; Play an auditory icon as you display the prompt
 (defun emacspeak-eshell-prompt-function ()
   "Play auditory icon for prompt."
-  (declare (special eshell-last-command-status))
+  (cl-declare (special eshell-last-command-status))
   (cond
    ((= 0 eshell-last-command-status)
     (emacspeak-auditory-icon 'item))
@@ -71,7 +72,7 @@
 
 (defun emacspeak-eshell-speak-output  ()
   "Speak eshell output."
-  (declare (special eshell-last-input-end eshell-last-output-end
+  (cl-declare (special eshell-last-input-end eshell-last-output-end
                     eshell-last-output-start))
   (emacspeak-speak-region eshell-last-input-end eshell-last-output-end))
 
@@ -98,20 +99,20 @@ Provide an auditory icon if possible."
 ;;{{{ advice em-hist
 
 (cl-loop for f in
-      '(
-        eshell-next-input eshell-previous-input
-                          eshell-next-matching-input eshell-previous-matching-input
-                          eshell-next-matching-input-from-input eshell-previous-matching-input-from-input)
-      do
-      (eval
-       `(defadvice ,f (after  emacspeak pre act comp)
-          "Speak selected command."
-          (when (ems-interactive-p)
-            (emacspeak-auditory-icon 'select-object)
-            (save-excursion
-              (beginning-of-line)
-              (eshell-skip-prompt)
-              (emacspeak-speak-line 1))))))
+         '(
+           eshell-next-input eshell-previous-input
+           eshell-next-matching-input eshell-previous-matching-input
+           eshell-next-matching-input-from-input eshell-previous-matching-input-from-input)
+         do
+         (eval
+          `(defadvice ,f (after  emacspeak pre act comp)
+             "Speak selected command."
+             (when (ems-interactive-p)
+               (emacspeak-auditory-icon 'select-object)
+               (save-excursion
+                 (beginning-of-line)
+                 (eshell-skip-prompt)
+                 (emacspeak-speak-line 1))))))
 
 ;;}}}
 ;;{{{  advice em-ls
@@ -163,33 +164,33 @@ personalities."
 ;;{{{ Advice em-prompt
 
 (cl-loop for f in
-      '(
-        eshell-next-prompt eshell-previous-prompt
-                           eshell-forward-matching-input  eshell-backward-matching-input)
-      do
-      (eval
-       `(defadvice ,f (after  emacspeak pre act comp)
-          "Speak selected command."
-          (when (ems-interactive-p)
-            (let ((emacspeak-speak-messages nil))
-              (emacspeak-auditory-icon 'select-object)
-              (emacspeak-speak-line 1))))))
+         '(
+           eshell-next-prompt eshell-previous-prompt
+           eshell-forward-matching-input  eshell-backward-matching-input)
+         do
+         (eval
+          `(defadvice ,f (after  emacspeak pre act comp)
+             "Speak selected command."
+             (when (ems-interactive-p)
+               (let ((emacspeak-speak-messages nil))
+                 (emacspeak-auditory-icon 'select-object)
+                 (emacspeak-speak-line 1))))))
 
 ;;}}}
 ;;{{{  advice esh-arg
 
 (cl-loop for f in
-      '(
-        eshell-insert-buffer-name
-        eshell-insert-process
-        eshell-insert-envvar)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Speak output."
-          (when (ems-interactive-p)
-            (emacspeak-auditory-icon 'select-object)
-            (emacspeak-speak-line)))))
+         '(
+           eshell-insert-buffer-name
+           eshell-insert-process
+           eshell-insert-envvar)
+         do
+         (eval
+          `(defadvice ,f (after emacspeak pre act comp)
+             "Speak output."
+             (when (ems-interactive-p)
+               (emacspeak-auditory-icon 'select-object)
+               (emacspeak-speak-line)))))
 
 (defadvice eshell-insert-process (after emacspeak pre
                                         act comp)
@@ -326,7 +327,7 @@ personalities."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
