@@ -45,6 +45,7 @@
 ;;}}}
 ;;{{{ required modules 
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (eval-when-compile
   (condition-case nil
@@ -55,18 +56,18 @@
 ;;{{{ Update command remap list.
 (defadvice table--make-cell-map(after emacspeak pre act comp)
   "Set up emacspeak for table.el"
-  (declare (special table-cell-map))
+  (cl-declare (special table-cell-map))
   (when  table-cell-map
     (cl-loop for k in
-          (where-is-internal 'emacspeak-self-insert-command (list table-cell-map))
-          do
-          (define-key table-cell-map k '*table--cell-self-insert-command))
+             (where-is-internal 'emacspeak-self-insert-command (list table-cell-map))
+             do
+             (define-key table-cell-map k '*table--cell-self-insert-command))
     (cl-loop for k in
-          '(
-            ("S-TAB" table-backward-cell)
-            ("\C-e." emacspeak-etable-speak-cell))
-          do
-          (emacspeak-keymap-update table-cell-map k))))
+             '(
+               ("S-TAB" table-backward-cell)
+               ("\C-e." emacspeak-etable-speak-cell))
+             do
+             (emacspeak-keymap-update table-cell-map k))))
 
 ;;}}}
 ;;{{{ Advice edit commands
@@ -116,7 +117,7 @@
   "Speak the previous line if line echo is on.
 See command \\[emacspeak-toggle-line-echo].  Otherwise cue the user to
 the newly created blank line."
-  (declare (special emacspeak-line-echo))
+  (cl-declare (special emacspeak-line-echo))
   (when (ems-interactive-p)
     (table--finish-delayed-tasks)
     (cond
@@ -128,7 +129,7 @@ the newly created blank line."
   "Speak the previous line if line echo is on.
 See command \\[emacspeak-toggle-line-echo].
 Otherwise cue user to the line just created."
-  (declare (special emacspeak-line-echo))
+  (cl-declare (special emacspeak-line-echo))
   (cond
    ((ems-interactive-p)
     (cond
@@ -169,16 +170,16 @@ Otherwise cue user to the line just created."
      (t (error "Cant identify cell.")))))
 
 (cl-loop for f in
-      '(table-forward-cell table-backward-cell)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory feedback by speaking current cell
+         '(table-forward-cell table-backward-cell)
+         do
+         (eval
+          `(defadvice ,f (after emacspeak pre act comp)
+             "Provide auditory feedback by speaking current cell
       contents."
-          (when (ems-interactive-p)
-            (table--finish-delayed-tasks)
-            (emacspeak-auditory-icon 'select-object)
-            (emacspeak-etable-speak-cell)))))
+             (when (ems-interactive-p)
+               (table--finish-delayed-tasks)
+               (emacspeak-auditory-icon 'select-object)
+               (emacspeak-etable-speak-cell)))))
 
 ;;}}}
 (provide  'emacspeak-etable)
@@ -186,7 +187,7 @@ Otherwise cue user to the line just created."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
