@@ -51,6 +51,7 @@
 ;;}}}
 ;;{{{ required modules
 (require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'eww)
 (require 'emacspeak-eww)
@@ -137,22 +138,22 @@
  for f in
  '(
    org-mark-ring-goto org-mark-ring-push
-                      org-next-visible-heading org-previous-visible-heading
-                      org-forward-heading-same-level org-backward-heading-same-level
-                      org-backward-sentence org-forward-sentence
-                      org-backward-element org-forward-element
-                      org-backward-paragraph org-forward-paragraph
-                      org-next-link org-previous-link org-open-at-point
-                      org-goto  org-goto-ret
-                      org-goto-left org-goto-right
-                      org-goto-quit
-                      org-next-item org-previous-item
-                      org-metaleft org-metaright org-metaup org-metadown
-                      org-meta-return
-                      org-shiftmetaleft org-shiftmetaright org-shiftmetaup org-shiftmetadown
-                      org-mark-element org-mark-subtree
-                      org-agenda-forward-block org-agenda-backward-block
-                      )
+   org-next-visible-heading org-previous-visible-heading
+   org-forward-heading-same-level org-backward-heading-same-level
+   org-backward-sentence org-forward-sentence
+   org-backward-element org-forward-element
+   org-backward-paragraph org-forward-paragraph
+   org-next-link org-previous-link org-open-at-point
+   org-goto  org-goto-ret
+   org-goto-left org-goto-right
+   org-goto-quit
+   org-next-item org-previous-item
+   org-metaleft org-metaright org-metaup org-metadown
+   org-meta-return
+   org-shiftmetaleft org-shiftmetaright org-shiftmetaup org-shiftmetadown
+   org-mark-element org-mark-subtree
+   org-agenda-forward-block org-agenda-backward-block
+   )
  do
  (eval
   `(defadvice ,f(after emacspeak pre act comp)
@@ -166,7 +167,11 @@
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'item)
     (emacspeak-speak-line)))
-
+;;; orgstruct-mode defines structured navigators that in turn call org-cycle.
+;;; Removing itneractive check in advice for org-cycle 
+;;; to speech enable all such nav commands.
+;;; Note that org itself produces the folded state via org-unlogged-message
+;;; Which gets spoken by Emacspeak
 (cl-loop
  for f in
  '(org-cycle org-shifttab)
@@ -174,13 +179,13 @@
  (eval
   `(defadvice ,f(after emacspeak pre act comp)
      "Provide auditory feedback."
-     (when (ems-interactive-p)
-       (cond
-        ((org-at-table-p 'any)
-         (emacspeak-org-table-speak-current-element))
-        (t
-         (emacspeak-speak-line)
-         (emacspeak-auditory-icon 'select-object)))))))
+     (cond
+      ((org-at-table-p 'any)
+       (emacspeak-org-table-speak-current-element))
+      (t
+;;; org produces relevant feedback via org-unlogged-message (folded, children)
+       (let ((dtk-stop-immediately nil))
+         (emacspeak-speak-line)))))))
 
 (defadvice org-overview (after emacspeak pre act comp)
   "Provide auditory feedback."
@@ -229,8 +234,8 @@
 (cl-loop for f in
          '(
            org-cut-subtree org-copy-subtree
-                           org-paste-subtree org-archive-subtree
-                           org-narrow-to-subtree)
+           org-paste-subtree org-archive-subtree
+           org-narrow-to-subtree)
          do
          (eval
           `(defadvice ,f(after emacspeak pre act comp)
@@ -300,7 +305,7 @@
 
 (defadvice org-eval-in-calendar (after emacspeak pre act comp)
   "Speak what is returned."
-  (declare (special org-ans2))
+  (cl-declare (special org-ans2))
   (dtk-speak org-ans2))
 
 ;;}}}
@@ -312,9 +317,9 @@
  for f in
  '(
    org-agenda-next-date-line org-agenda-previous-date-line
-                             org-agenda-next-line org-agenda-previous-line
-                             org-agenda-goto-today
-                             )
+   org-agenda-next-line org-agenda-previous-line
+   org-agenda-goto-today
+   )
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
@@ -359,7 +364,7 @@
 
 (defadvice orgtbl-mode (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (declare (special orgtbl-mode))
+  (cl-declare (special orgtbl-mode))
   (when (ems-interactive-p)
     (emacspeak-auditory-icon (if orgtbl-mode 'on 'off))
     (message "Turned %s org table mode."
@@ -370,7 +375,7 @@
 
 (defun emacspeak-org-update-keys ()
   "Update keys in org mode."
-  (declare (special  org-mode-map))
+  (cl-declare (special  org-mode-map))
   (cl-loop for k in
            '(
              ("C-e" emacspeak-prefix-command)
@@ -396,7 +401,7 @@
            do
            (emacspeak-keymap-update  org-mode-map k)))
 
-(add-hook 'org-mode-hook 'emacspeak-org-update-keys)
+(add-hook 'org-mode-hook #'emacspeak-org-update-keys)
 
 ;;}}}
 ;;{{{ deleting chars:
@@ -436,13 +441,13 @@
 
 (defun emacspeak-org-mode-setup ()
   "Placed on org-mode-hook to do Emacspeak setup."
-  (declare (special org-mode-map))
-  (unless emacspeak-audio-indentation (emacspeak-toggle-audio-indentation))
+  (cl-declare (special org-mode-map))
   (when (fboundp 'org-end-of-line)
-    (define-key org-mode-map emacspeak-prefix  'emacspeak-prefix-command)))
-
-(add-hook 'org-mode-hook 'emacspeak-org-mode-setup)
+    (define-key org-mode-map emacspeak-prefix  'emacspeak-prefix-command)
+    (emacspeak-setup-programming-mode)))
 
+(add-hook 'org-mode-hook #'emacspeak-org-mode-setup)
+(add-hook 'orgstruct-mode-hook #'emacspeak-org-mode-setup)
 ;;; advice end-of-line here to call org specific action
 (defadvice end-of-line (after emacspeak-org pre act comp)
   "Call org specific actions in org mode."
@@ -494,7 +499,7 @@
 (defun emacspeak-org-bookmark (&optional goto)
   "Bookmark from org."
   (interactive "P")
-  (declare (special emacspeak-org-bookmark-key))
+  (cl-declare (special emacspeak-org-bookmark-key))
   (org-capture goto emacspeak-org-bookmark-key))
 
 (defadvice org-capture-goto-last-stored (after emacspeak pre act comp)
@@ -633,10 +638,11 @@ and assign  letter `h' to a template that creates the hyperlink on capture."
      :description (emacspeak-eww-current-title))))
 
 (unless (functionp 'org-store-link-functions)
-  ;;; org-mode 8.x and earlier:
+;;; org-mode 8.x and earlier:
   (add-hook
    'org-load-hook
    #'(lambda nil
+       (cl-declare (special org-store-link-functions))
        (push #'org-eww-store-link org-store-link-functions))))
 
 ;;}}}
@@ -658,7 +664,6 @@ and assign  letter `h' to a template that creates the hyperlink on capture."
           (format "%c: %s\n" (cl-first e) (cl-second e)))
       choices "\n"))
     (sit-for 5)))
-    
 
 ;;}}}
 ;;{{{ Preview HTML With EWW:
@@ -668,12 +673,37 @@ and assign  letter `h' to a template that creates the hyperlink on capture."
   (funcall-interactively #'eww-open-file file))
 
 ;;}}}
+;;{{{ Edit Special Advice:
+
+(cl-loop
+ for f in 
+ '(org-edit-src-exit org-edit-src-abort)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Provide auditory feedback."
+     (when (ems-interactive-p)
+       (emacspeak-auditory-icon 'close-object)
+       (emacspeak-speak-line)))))
+
+(cl-loop
+ for f in
+ '(org-edit-src-code org-edit-special) do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Provide auditory feedback."
+     (when (ems-interactive-p)
+       (emacspeak-auditory-icon 'open-object)
+       (emacspeak-speak-mode-line)))))
+
+;;}}}
+
 (provide 'emacspeak-org)
 ;;{{{ end of file
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
