@@ -47,6 +47,7 @@
 
 ;;}}}
 ;;{{{ requires
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'outline)
 
@@ -179,7 +180,7 @@ sections."
 (defun emacspeak-outline-speak-heading (what direction)
   "Function used by all interactive section speaking
 commands. "
-  (declare (special emacspeak-outline-query-before-speaking))
+  (cl-declare (special emacspeak-outline-query-before-speaking))
   (let ((start nil)
         (end nil))
     (funcall what  direction)
@@ -196,28 +197,28 @@ commands. "
                 (format  "Speak %s lines from section %s"
                          (count-lines start end) (ems-this-line))))
       (emacspeak-speak-region start end))))
-
+;;;###autoload
 (defun emacspeak-outline-speak-next-heading ()
   "Analogous to outline-next-visible-heading,
 except that the outline section is  spoken"
   (interactive)
   (emacspeak-auditory-icon 'section)
   (emacspeak-outline-speak-heading 'outline-next-visible-heading 1))
-
+;;;###autoload
 (defun emacspeak-outline-speak-previous-heading ()
   "Analogous to outline-previous-visible-heading,
 except that the outline section is  spoken"
   (interactive)
   (emacspeak-auditory-icon 'section)
   (emacspeak-outline-speak-heading 'outline-next-visible-heading -1))
-
+;;;###autoload
 (defun emacspeak-outline-speak-forward-heading ()
   "Analogous to outline-forward-same-level,
 except that the outline section is  spoken"
   (interactive)
   (emacspeak-auditory-icon 'section)
   (emacspeak-outline-speak-heading 'outline-forward-same-level 1))
-
+;;;###autoload
 (defun emacspeak-outline-speak-backward-heading ()
   "Analogous to outline-backward-same-level
 except that the outline section is  spoken"
@@ -225,6 +226,9 @@ except that the outline section is  spoken"
   (emacspeak-auditory-icon 'section)
   (forward-line -1)
   (emacspeak-outline-speak-heading 'outline-forward-same-level -1))
+
+
+;;;###autoload
 (defun emacspeak-outline-speak-this-heading ()
   "Speak current outline section starting from point"
   (interactive)
@@ -247,7 +251,7 @@ except that the outline section is  spoken"
 
 (defun emacspeak-outline-setup-keys ()
   "Bind keys in outline minor mode map"
-  (declare (special outline-mode-prefix-map))
+  (cl-declare (special outline-mode-prefix-map))
   (define-key outline-mode-prefix-map "p"
     'emacspeak-outline-speak-previous-heading)
   (define-key outline-mode-prefix-map "n"
@@ -309,7 +313,7 @@ except that the outline section is  spoken"
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
