@@ -93,8 +93,8 @@
 ;;}}}
 ;;{{{  Required modules
 
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'custom)
 (require 'emacspeak-speak)
 (require 'emacspeak-sounds)
@@ -320,7 +320,7 @@ Simple means that voiceification is not cumulative."
           (voice nil)
           (value nil))
       (setq facep (emacspeak-personality-plist-face-p properties))
-      (when facep (setq value (second facep))
+      (when facep (setq value (cl-second facep))
             (setq voice (ems-get-voice-for-face value))
             (when voice
               (funcall emacspeak-personality-voiceify-faces start end voice object))))))
@@ -337,7 +337,7 @@ Simple means that voiceification is not cumulative."
           (value nil))
       (setq facep (emacspeak-personality-plist-face-p properties))
       (when  facep
-        (setq value (second facep))
+        (setq value (cl-second facep))
         (setq voice (ems-get-voice-for-face value))
         
         (when voice
@@ -355,7 +355,7 @@ Simple means that voiceification is not cumulative."
      ((and  emacspeak-personality-voiceify-faces
             voice-lock-mode facep)
       ad-do-it
-      (setq value (second facep))
+      (setq value (cl-second facep))
       (setq voice (ems-get-voice-for-face value))
       (when voice
         (funcall emacspeak-personality-voiceify-faces 0
@@ -461,7 +461,7 @@ Append means place corresponding personality at the end."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
