@@ -61,18 +61,18 @@
 ;;; Code:
 ;;{{{ required packages
 
-(require 'cl)
-(declaim (optimize (safety 0) (speed 3)))
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'custom)
 (eval-when-compile (require 'calendar))
 
 (require 'voice-setup)
 (require 'thingatpt)
-(eval-when (compile)
+(cl-eval-when (compile)
                                         ;avoid recursive include during compile
-  (provide 'emacspeak-pronounce)
-  (require 'dtk-speak)
-  (require 'emacspeak-sounds))
+           (provide 'emacspeak-pronounce)
+           (require 'dtk-speak)
+           (require 'emacspeak-sounds))
 
 ;;}}}
 ;;{{{ customizations
@@ -90,13 +90,13 @@ Keys are either filenames, directory names, or major mode names.
 Values are alists containing string.pronunciation pairs.")
 
 (defun emacspeak-pronounce-set-dictionary (key pr-alist)
-  (declare (special emacspeak-pronounce-dictionaries))
+  (cl-declare (special emacspeak-pronounce-dictionaries))
   (when (stringp key)
     (setq key (intern key)))
   (setf (gethash key emacspeak-pronounce-dictionaries) pr-alist))
 
 (defun emacspeak-pronounce-get-dictionary (key)
-  (declare (special emacspeak-pronounce-dictionaries
+  (cl-declare (special emacspeak-pronounce-dictionaries
                     minibuffer-history))
   (when (stringp key)
     (setq key (intern key)))
@@ -108,7 +108,7 @@ Values are alists containing string.pronunciation pairs.")
 This adds pronunciation pair
 STRING.PRONUNCIATION to the dictionary.
 Argument KEY specifies a dictionary key e.g. directory, mode etc."
-  (declare (special emacspeak-pronounce-dictionaries))
+  (cl-declare (special emacspeak-pronounce-dictionaries))
   (let* ((dict (emacspeak-pronounce-get-dictionary key))
          (entry (and dict (assoc string dict))))
     (cond
@@ -131,7 +131,7 @@ Argument KEY specifies a dictionary key e.g. directory, mode etc."
 (defun emacspeak-pronounce-add-buffer-local-dictionary-entry (string pronunciation)
   "Add specified pronunciation for current buffer.
 Arguments STRING and PRONUNCIATION specify what is being defined."
-  (declare (special emacspeak-pronounce-pronunciation-table))
+  (cl-declare (special emacspeak-pronounce-pronunciation-table))
   (cond
    ((not (boundp 'emacspeak-pronounce-pronunciation-table)) ;first time
     (set (make-local-variable 'emacspeak-pronounce-pronunciation-table)
@@ -190,20 +190,20 @@ modes."
          (mode-alist (emacspeak-pronounce-get-dictionary mode))
          (super-alist nil))
     (cl-loop for super in mode-supers
-          do
-          (setq super-alist (emacspeak-pronounce-get-dictionary super))
-          (cl-loop for element in super-alist
-                do
-                (puthash (car element) (cdr element) table)))
+             do
+             (setq super-alist (emacspeak-pronounce-get-dictionary super))
+             (cl-loop for element in super-alist
+                      do
+                      (puthash (car element) (cdr element) table)))
     (cl-loop for element in mode-alist
-          do
-          (puthash (car element) (cdr element) table))
+             do
+             (puthash (car element) (cdr element) table))
     (cl-loop for element in dir-alist
-          do
-          (puthash (car element) (cdr element) table))
+             do
+             (puthash (car element) (cdr element) table))
     (cl-loop for element in file-alist
-          do
-          (puthash (car element) (cdr element) table))
+             do
+             (puthash (car element) (cdr element) table))
     table))
 
 ;;}}}
@@ -229,8 +229,7 @@ modes."
 ;;;xsl inherits from xml
 (emacspeak-pronounce-add-super 'xml-mode 'xsl-mode)
 
-;;; VM, w3m, w3
-(emacspeak-pronounce-add-super 'text-mode 'w3m-mode)
+;;; VM,  w3
 (emacspeak-pronounce-add-super 'text-mode 'w3-mode)
 (emacspeak-pronounce-add-super 'text-mode 'vm-presentation-mode)
 
@@ -263,7 +262,7 @@ applied."
 ;;}}}
 ;;{{{ loading, clearing and saving dictionaries
 
-(declaim (special emacspeak-resource-directory))
+(cl-declaim (special emacspeak-resource-directory))
 
 (defcustom emacspeak-pronounce-dictionaries-file
   (expand-file-name ".dictionary"
@@ -280,8 +279,8 @@ applied."
 (defun emacspeak-pronounce-save-dictionaries ()
   "Writes out the persistent emacspeak pronunciation dictionaries."
   (interactive)
-  (declare (special emacspeak-pronounce-dictionaries))
-  (let* (
+  (cl-declare (special emacspeak-pronounce-dictionaries))
+  (let* ((coding-system-for-write 'utf-8)
          (print-level nil)
          (print-length nil)
          (filename (read-file-name
@@ -296,11 +295,11 @@ applied."
       (auto-fill-mode nil)
       (erase-buffer)
       (cl-loop for key being the hash-keys of emacspeak-pronounce-dictionaries
-            do
-            (insert
-             (format "(emacspeak-pronounce-set-dictionary '%S\n '%S)\n"
-                     key
-                     (emacspeak-pronounce-get-dictionary key))))
+               do
+               (insert
+                (format "(emacspeak-pronounce-set-dictionary '%S\n '%S)\n"
+                        key
+                        (emacspeak-pronounce-get-dictionary key))))
       (save-buffer))))
 
 (defvar emacspeak-pronounce-dictionaries-loaded nil
@@ -314,12 +313,14 @@ Optional argument FILENAME specifies the dictionary file."
           "Load pronunciation dictionaries from file: "
           emacspeak-resource-directory
           emacspeak-pronounce-dictionaries-file)))
-  (declare (special emacspeak-pronounce-dictionaries-loaded))
+  (cl-declare (special emacspeak-pronounce-dictionaries-loaded))
   (when (file-exists-p filename)
     (condition-case nil
-        (progn
-          (load-file filename)
-          (setq emacspeak-pronounce-dictionaries-loaded t))
+        (let ((coding-system-for-read  'utf-8)
+              (file-name-handler-alist  nil))
+          (progn
+            (load-file filename)
+            (setq emacspeak-pronounce-dictionaries-loaded t)))
       (error
        (message "Error loading pronunciation dictionary, deactivating  pronunciations.")
        (setq emacspeak-pronounce-dictionaries (make-hash-table)
@@ -329,7 +330,7 @@ Optional argument FILENAME specifies the dictionary file."
 (defun emacspeak-pronounce-clear-dictionaries ()
   "Clear all current pronunciation dictionaries."
   (interactive)
-  (declare (special emacspeak-pronounce-dictionaries))
+  (cl-declare (special emacspeak-pronounce-dictionaries))
   (when (yes-or-no-p
          "Do you really want to nuke all currently defined dictionaries?")
     (setq emacspeak-pronounce-dictionaries (make-hash-table))
@@ -356,7 +357,7 @@ Optional argument FILENAME specifies the dictionary file."
 (defun emacspeak-pronounce-yank-word ()
   "Yank word at point into minibuffer."
   (interactive)
-  (declare (special emacspeak-pronounce-yank-word-point
+  (cl-declare (special emacspeak-pronounce-yank-word-point
                     emacspeak-pronounce-current-buffer))
   (let ((string
          (save-current-buffer
@@ -371,7 +372,7 @@ Optional argument FILENAME specifies the dictionary file."
     (dtk-speak string)))
 
 (defun emacspeak-pronounce-read-term (key)
-  (declare (special emacspeak-pronounce-yank-word-point
+  (cl-declare (special emacspeak-pronounce-yank-word-point
                     emacspeak-pronounce-current-buffer))
   (let ((default (and (mark)
                       (< (count-lines (region-beginning)
@@ -403,7 +404,7 @@ Argument WORD specifies the word which should be pronounced as specified by PRON
 (defun emacspeak-pronounce-get-key ()
   "Collect key from user.
 Returns a pair of the form (key-type . key)."
-  (declare (special emacspeak-pronounce-pronunciation-keys))
+  (cl-declare (special emacspeak-pronounce-pronunciation-keys))
   (let ((key nil)
         (key-type
          (read
@@ -442,7 +443,7 @@ Returns a pair of the form (key-type . key)."
 Default term to define is delimited by region.
 First loads any persistent dictionaries if not already loaded."
   (interactive)
-  (declare (special emacspeak-pronounce-dictionaries-loaded))
+  (cl-declare (special emacspeak-pronounce-dictionaries-loaded))
   (let ((word nil)
         (pronunciation nil)
         (key-pair (emacspeak-pronounce-get-key)))
@@ -468,7 +469,7 @@ First loads any persistent dictionaries if not already loaded."
 Default term to define is delimited by region.
 First loads any persistent dictionaries if not already loaded."
   (interactive)
-  (declare (special emacspeak-pronounce-dictionaries-loaded))
+  (cl-declare (special emacspeak-pronounce-dictionaries-loaded))
   (let ((word nil)
         (pronunciation nil)
         (key-pair(emacspeak-pronounce-get-key)))
@@ -512,7 +513,7 @@ buffer is spoken.
 Optional argument state can be used from Lisp programs to
 explicitly turn pronunciations on or off."
   (interactive "P")
-  (declare (special emacspeak-pronounce-pronunciation-table))
+  (cl-declare (special emacspeak-pronounce-pronunciation-table))
   (cond
    ((or (eq state 'on)
         (not (boundp 'emacspeak-pronounce-pronunciation-table)))
@@ -542,7 +543,7 @@ explicitly turn pronunciations on or off."
   "Refresh pronunciation table for current buffer.
 Activates pronunciation dictionaries if not already active."
   (interactive)
-  (declare (special emacspeak-pronounce-pronunciation-table))
+  (cl-declare (special emacspeak-pronounce-pronunciation-table))
   (cond
    ((not (boundp 'emacspeak-pronounce-pronunciation-table)) ;first time
     (set (make-local-variable 'emacspeak-pronounce-pronunciation-table)
@@ -623,10 +624,10 @@ See http://www.charm.net/~kmarsh/smiley.html. "
 for the specified mode."
   (let ((mode-alist (emacspeak-pronounce-get-dictionary mode)))
     (cl-loop for e in dictionary
-          do
-          (unless (assoc (car e)
-                         mode-alist)
-            (push e mode-alist)))
+             do
+             (unless (assoc (car e)
+                            mode-alist)
+               (push e mode-alist)))
     (emacspeak-pronounce-set-dictionary mode mode-alist)))
 
 ;;}}}
@@ -635,7 +636,7 @@ for the specified mode."
 (defun emacspeak-pronounce-edit-generate-pronunciation-editor (key)
   "Generate a widget-enabled edit buffer for editing the
 pronunciation dictionary for the specified key."
-  (declare (special emacspeak-pronounce-dictionaries))
+  (cl-declare (special emacspeak-pronounce-dictionaries))
   (unless emacspeak-pronounce-pronunciation-table
     (emacspeak-pronounce-toggle-use-of-dictionaries))
   (let ((value (gethash key emacspeak-pronounce-dictionaries))
@@ -677,7 +678,7 @@ pronunciation dictionary for the specified key."
 (defun emacspeak-pronounce-edit-generate-callback (field-name)
   "Generate a callback for use in the pronunciation editor widget."
   `(lambda (widget &rest ignore)
-     (declare (special emacspeak-pronounce-dictionaries))
+     (cl-declare (special emacspeak-pronounce-dictionaries))
      (let ((value (widget-value widget)))
        (setf
         (gethash
@@ -693,9 +694,9 @@ specified pronunciation dictionary key."
    (list
     (let ((keys
            (cl-loop for k being the hash-keys of
-                 emacspeak-pronounce-dictionaries
-                 collect
-                 (symbol-name k))))
+                    emacspeak-pronounce-dictionaries
+                    collect
+                    (symbol-name k))))
       (completing-read "Edit dictionary: "
                        (mapcar
                         #'(lambda (k)
@@ -706,7 +707,7 @@ specified pronunciation dictionary key."
                        nil
                        'keys
                        (car keys)))))
-  (declare (special emacspeak-pronounce-dictionaries))
+  (cl-declare (special emacspeak-pronounce-dictionaries))
   (emacspeak-pronounce-edit-generate-pronunciation-editor
    (intern key)))
 
@@ -721,21 +722,21 @@ specified pronunciation dictionary key."
 (defun emacspeak-pronounce-dispatch ()
   "Provides the user interface front-end to Emacspeak's pronunciation dictionaries."
   (interactive)
-  (declare (special emacspeak-pronounce-help))
+  (cl-declare (special emacspeak-pronounce-help))
   (message emacspeak-pronounce-help)
   (let ((event (read-char)))
-    (case event
-      (?c (call-interactively 'emacspeak-pronounce-clear-dictionaries))
-      (?d (call-interactively
-           'emacspeak-pronounce-define-pronunciation t))
-      (?D (call-interactively 'emacspeak-pronounce-define-template-pronunciation t))
-      (?e (call-interactively
-           'emacspeak-pronounce-edit-pronunciations t))
-      (?l (call-interactively 'emacspeak-pronounce-load-dictionaries))
-      (?r (call-interactively 'emacspeak-pronounce-refresh-pronunciations))
-      (?s (call-interactively 'emacspeak-pronounce-save-dictionaries))
-      (?t (call-interactively 'emacspeak-pronounce-toggle-use-of-dictionaries))
-      (otherwise (message emacspeak-pronounce-help)))
+    (cl-case event
+          (?c (call-interactively 'emacspeak-pronounce-clear-dictionaries))
+          (?d (call-interactively
+               'emacspeak-pronounce-define-pronunciation t))
+          (?D (call-interactively 'emacspeak-pronounce-define-template-pronunciation t))
+          (?e (call-interactively
+               'emacspeak-pronounce-edit-pronunciations t))
+          (?l (call-interactively 'emacspeak-pronounce-load-dictionaries))
+          (?r (call-interactively 'emacspeak-pronounce-refresh-pronunciations))
+          (?s (call-interactively 'emacspeak-pronounce-save-dictionaries))
+          (?t (call-interactively 'emacspeak-pronounce-toggle-use-of-dictionaries))
+          (otherwise (message emacspeak-pronounce-help)))
     (emacspeak-auditory-icon 'close-object)))
 
 ;;}}}
@@ -753,14 +754,14 @@ specified pronunciation dictionary key."
     (let ((fields (mapcar #'read (split-string string "-"))))
       (propertize
        (calendar-date-string
-        (list (second fields)
-              (first fields)
+        (list (cl-second fields)
+              (cl-first fields)
               (cond
-               ((< (third fields) 50)
-                (+ 2000 (third fields)))
-               ((< (third fields) 100)
-                (+ 1900 (third fields)))
-               (t (third fields)))))
+               ((< (cl-third fields) 50)
+                (+ 2000 (cl-third fields)))
+               ((< (cl-third fields) 100)
+                (+ 1900 (cl-third fields)))
+               (t (cl-third fields)))))
        'personality voice-punctuations-some))))
 
 (defvar emacspeak-pronounce-date-yyyymmdd-pattern
@@ -829,7 +830,7 @@ specified pronunciation dictionary key."
 
 (defun emacspeak-pronounce-uuid (uuid)
   "Return pronunciation for human-readable UUID."
-  (declare (special emacspeak-pronounce-uuid-pattern))
+  (cl-declare (special emacspeak-pronounce-uuid-pattern))
   (when (and (= 36 (length uuid))
              (string-match emacspeak-pronounce-uuid-pattern uuid))
     (format "uid: %s..%s "
@@ -845,7 +846,7 @@ specified pronunciation dictionary key."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
