@@ -48,7 +48,8 @@
 
 ;;}}}
 ;;{{{  Required modules
-(require 'cl)
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (eval-when-compile
   (require 'python-mode "python-mode" 'no-error))
@@ -204,100 +205,100 @@ Provide contextual feedback when closing blocks"
  for f in
  '(
    py-goto-block-or-clause-up py-goto-clause-up
-                              py-previous-class py-previous-clause py-previous-def-or-class
-                              py-forward-block
-                              py-forward-block-bol
-                              py-forward-block-or-clause
-                              py-forward-block-or-clause-bol
-                              py-forward-buffer
-                              py-forward-class
-                              py-forward-class-bol
-                              py-forward-clause
-                              py-forward-clause-bol
-                              py-forward-comment
-                              py-forward-decorator
-                              py-forward-def-bol
-                              py-forward-def-or-class-bol
-                              py-forward-elif-block
-                              py-forward-elif-block-bol
-                              py-forward-else-block
-                              py-forward-else-block-bol
-                              py-forward-except-block
-                              py-forward-except-block-bol
-                              py-forward-expression
-                              py-forward-for-block
-                              py-forward-for-block-bol
-                              py-forward-function
-                              py-forward-if-block
-                              py-forward-if-block-bol
-                              py-forward-line
-                              py-forward-minor-block
-                              py-forward-minor-block-bol
-                              py-forward-paragraph
-                              py-forward-partial-expression
-                              py-forward-section
-                              py-forward-statement-bol
-                              py-forward-statements
-                              py-forward-top-level
-                              py-forward-top-level-bol
-                              py-forward-try-block
-                              py-forward-try-block-bol
-                              py-backward-block py-backward-block-bol
-                              py-backward-block-or-clause py-backward-block-or-clause-bol
-                              py-backward-class py-backward-class-bol
-                              py-backward-clause py-backward-clause-bol
-                              py-backward-comment py-backward-decorator py-backward-decorator-bol
-                              py-backward-def-bol py-backward-def-or-class-bol
-                              py-backward-elif-block py-backward-elif-block-bol
-                              py-backward-else-block py-backward-else-block-bol
-                              py-backward-except-block py-backward-except-block-bol
-                              py-backward-expression py-backward-for-block py-backward-for-block-bol
-                              py-backward-function py-backward-if-block py-backward-if-block-bol
-                              py-backward-line py-backward-minor-block py-backward-minor-block-bol
-                              py-backward-paragraph py-backward-partial-expression py-backward-same-level
-                              py-backward-section py-backward-statement-bol py-backward-statements
-                              py-backward-top-level py-backward-top-level-p
-                              py-backward-try-block py-backward-try-block-bol
-                              py-match-paren py-indent-or-complete
-                              py-beginning py-beginning-of-block-bol
-                              py-beginning-of-block-current-column
-                              py-beginning-of-block-or-clause py-beginning-of-class
-                              py-beginning-of-class-bol
-                              py-beginning-of-clause-bol py-beginning-of-comment py-beginning-of-declarations
-                              py-beginning-of-decorator py-beginning-of-decorator-bol
-                              py-beginning-of-expression py-beginning-of-line
-                              py-beginning-of-list-pps
-                              py-beginning-of-minor-block
-                              py-beginning-of-partial-expression
-                              py-beginning-of-section py-beginning-of-statement-bol
-                              py-beginning-of-top-level
-                              py-forward-declarations py-backward-declarations
-                              py-down py-up
-                              py-down-block py-down-block-bol
-                              py-down-block-or-clause py-down-block-or-clause-bol
-                              py-down-class py-down-class-bol
-                              py-down-clause py-down-clause-bol
-                              py-down-def py-down-def-bol
-                              py-down-def-or-class py-down-def-or-class-bol
-                              py-down-minor-block py-down-minor-block-bol
-                              py-down-section py-down-section-bol
-                              py-down-statement py-down-top-level
-                              py-backward-statement py-forward-statement
-                              py-goto-block-up  py-go-to-beginning-of-comment
-                              py-end py-end-of-block-or-clause
-                              py-end-of-class py-end-of-comment
-                              py-end-of-decorator py-end-of-expression
-                              py-end-of-line py-end-of-list-position
-                              py-end-of-partial-expression py-end-of-section
-                              py-end-of-statement-bol py-end-of-string
-                              py-end-of-top-level
-                              py-beginning-of-statement py-end-of-statement
-                              py-beginning-of-block py-end-of-block
-                              py-beginning-of-clause py-end-of-clause
-                              py-next-statement py-previous-statement
-                              py-backward-def py-forward-def
-                              py-backward-def-or-class py-forward-def-or-class
-                              py-beginning-of-def-or-class py-end-of-def-or-class)
+   py-previous-class py-previous-clause py-previous-def-or-class
+   py-forward-block
+   py-forward-block-bol
+   py-forward-block-or-clause
+   py-forward-block-or-clause-bol
+   py-forward-buffer
+   py-forward-class
+   py-forward-class-bol
+   py-forward-clause
+   py-forward-clause-bol
+   py-forward-comment
+   py-forward-decorator
+   py-forward-def-bol
+   py-forward-def-or-class-bol
+   py-forward-elif-block
+   py-forward-elif-block-bol
+   py-forward-else-block
+   py-forward-else-block-bol
+   py-forward-except-block
+   py-forward-except-block-bol
+   py-forward-expression
+   py-forward-for-block
+   py-forward-for-block-bol
+   py-forward-function
+   py-forward-if-block
+   py-forward-if-block-bol
+   py-forward-line
+   py-forward-minor-block
+   py-forward-minor-block-bol
+   py-forward-paragraph
+   py-forward-partial-expression
+   py-forward-section
+   py-forward-statement-bol
+   py-forward-statements
+   py-forward-top-level
+   py-forward-top-level-bol
+   py-forward-try-block
+   py-forward-try-block-bol
+   py-backward-block py-backward-block-bol
+   py-backward-block-or-clause py-backward-block-or-clause-bol
+   py-backward-class py-backward-class-bol
+   py-backward-clause py-backward-clause-bol
+   py-backward-comment py-backward-decorator py-backward-decorator-bol
+   py-backward-def-bol py-backward-def-or-class-bol
+   py-backward-elif-block py-backward-elif-block-bol
+   py-backward-else-block py-backward-else-block-bol
+   py-backward-except-block py-backward-except-block-bol
+   py-backward-expression py-backward-for-block py-backward-for-block-bol
+   py-backward-function py-backward-if-block py-backward-if-block-bol
+   py-backward-line py-backward-minor-block py-backward-minor-block-bol
+   py-backward-paragraph py-backward-partial-expression py-backward-same-level
+   py-backward-section py-backward-statement-bol py-backward-statements
+   py-backward-top-level py-backward-top-level-p
+   py-backward-try-block py-backward-try-block-bol
+   py-match-paren py-indent-or-complete
+   py-beginning py-beginning-of-block-bol
+   py-beginning-of-block-current-column
+   py-beginning-of-block-or-clause py-beginning-of-class
+   py-beginning-of-class-bol
+   py-beginning-of-clause-bol py-beginning-of-comment py-beginning-of-declarations
+   py-beginning-of-decorator py-beginning-of-decorator-bol
+   py-beginning-of-expression py-beginning-of-line
+   py-beginning-of-list-pps
+   py-beginning-of-minor-block
+   py-beginning-of-partial-expression
+   py-beginning-of-section py-beginning-of-statement-bol
+   py-beginning-of-top-level
+   py-forward-declarations py-backward-declarations
+   py-down py-up
+   py-down-block py-down-block-bol
+   py-down-block-or-clause py-down-block-or-clause-bol
+   py-down-class py-down-class-bol
+   py-down-clause py-down-clause-bol
+   py-down-def py-down-def-bol
+   py-down-def-or-class py-down-def-or-class-bol
+   py-down-minor-block py-down-minor-block-bol
+   py-down-section py-down-section-bol
+   py-down-statement py-down-top-level
+   py-backward-statement py-forward-statement
+   py-goto-block-up  py-go-to-beginning-of-comment
+   py-end py-end-of-block-or-clause
+   py-end-of-class py-end-of-comment
+   py-end-of-decorator py-end-of-expression
+   py-end-of-line py-end-of-list-position
+   py-end-of-partial-expression py-end-of-section
+   py-end-of-statement-bol py-end-of-string
+   py-end-of-top-level
+   py-beginning-of-statement py-end-of-statement
+   py-beginning-of-block py-end-of-block
+   py-beginning-of-clause py-end-of-clause
+   py-next-statement py-previous-statement
+   py-backward-def py-forward-def
+   py-backward-def-or-class py-forward-def-or-class
+   py-beginning-of-def-or-class py-end-of-def-or-class)
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
@@ -310,15 +311,15 @@ Provide contextual feedback when closing blocks"
  for  f in
  '(
    py-mark-class-bol py-mark-clause py-mark-clause-bol py-mark-comment
-                     py-mark-comment-bol py-mark-def py-mark-def-bol
-                     py-mark-def-or-class py-mark-def-or-class-bol py-mark-except-block
-                     py-mark-except-block-bol py-mark-expression py-mark-expression-bol
-                     py-mark-if-block py-mark-if-block-bol py-mark-line py-mark-line-bol
-                     py-mark-minor-block py-mark-minor-block-bol py-mark-paragraph
-                     py-mark-paragraph-bol py-mark-partial-expression
-                     py-mark-partial-expression-bol py-mark-section py-mark-statement
-                     py-mark-statement-bol py-mark-top-level py-mark-top-level-bol
-                     py-mark-try-block py-mark-try-block-bol)
+   py-mark-comment-bol py-mark-def py-mark-def-bol
+   py-mark-def-or-class py-mark-def-or-class-bol py-mark-except-block
+   py-mark-except-block-bol py-mark-expression py-mark-expression-bol
+   py-mark-if-block py-mark-if-block-bol py-mark-line py-mark-line-bol
+   py-mark-minor-block py-mark-minor-block-bol py-mark-paragraph
+   py-mark-paragraph-bol py-mark-partial-expression
+   py-mark-partial-expression-bol py-mark-section py-mark-statement
+   py-mark-statement-bol py-mark-top-level py-mark-top-level-bol
+   py-mark-try-block py-mark-try-block-bol)
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
@@ -335,10 +336,10 @@ Provide contextual feedback when closing blocks"
  '(
 
    Possible completions are:
-            py-narrow-to-block  py-narrow-to-block-or-clause    py-narrow-to-class
-            py-narrow-to-clause         py-narrow-to-def        py-narrow-to-def-or-class
-            py-narrow-to-statement
-            )
+   py-narrow-to-block  py-narrow-to-block-or-clause    py-narrow-to-class
+   py-narrow-to-clause         py-narrow-to-def        py-narrow-to-def-or-class
+   py-narrow-to-statement
+   )
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
@@ -371,7 +372,7 @@ Provide contextual feedback when closing blocks"
 
 (defadvice py-process-filter (around emacspeak pre act)
   "Make comint in Python speak its output. "
-  (declare (special emacspeak-comint-autospeak))
+  (cl-declare (special emacspeak-comint-autospeak))
   (let ((prior (point))
         (dtk-stop-immediately nil))
     ad-do-it
@@ -392,11 +393,16 @@ Provide contextual feedback when closing blocks"
    (py-number-face voice-lighten)
    (py-XXX-tag-face voice-animate)
    (py-pseudo-keyword-face voice-bolden-medium)
-   (py-variable-name-face  emacspeak-voice-lock-variable-name-personality)
+   (py-variable-name-face  voice-bolden)
    (py-decorators-face voice-lighten)
-   (py-builtins-face emacspeak-voice-lock-builtin-personality)
+   (py-builtins-face voice-bolden)
    (py-class-name-face voice-bolden-extra)
-   (py-exception-name-face emacspeak-voice-lock-warning-personality)))
+   (py-exception-name-face voice-smoothen)
+   (py-def-class-face voice-lighten)
+   (py-import-from-face voice-animate)
+   (py-object-reference-face voice-monotone-light)
+   (py-try-if-face voice-lighten)
+   ))
 
 ;;}}}
 ;;{{{ pydoc advice:
@@ -413,7 +419,7 @@ Provide contextual feedback when closing blocks"
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
