@@ -39,6 +39,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Required modules
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction
@@ -73,7 +74,7 @@ a local  Emacspeak terminal buffer.")
 
 (defun emacspeak-remote-default-hook ()
   "Function run by default  when we launch a remote session"
-  (declare (special emacspeak-remote-update-keymap
+  (cl-declare (special emacspeak-remote-update-keymap
                     emacspeak-auditory-icon-function))
   (when emacspeak-remote-update-keymap
     (emacspeak-keymap-choose-new-emacspeak-prefix
@@ -88,7 +89,7 @@ a local  Emacspeak terminal buffer.")
 
 ;;;Remote hostname guessing
 ;;;
-(declaim (special emacspeak-resource-directory))
+(cl-declaim (special emacspeak-resource-directory))
 
 (defvar emacspeak-remote-hostname
   (expand-file-name  ".current-remote-hostname"
@@ -100,13 +101,13 @@ a local  Emacspeak terminal buffer.")
   "Interactively set up where we came from.
 Value is persisted for use with ssh servers."
   (interactive)
-  (declare (special emacspeak-remote-hostname))
+  (cl-declare (special emacspeak-remote-hostname))
   (when (file-exists-p   emacspeak-remote-hostname)
     (find-file emacspeak-remote-hostname)))
 ;;; Todo: parse out hostname if the file has user@host:port
 (defun emacspeak-remote-get-current-remote-hostname  ()
   "Return the name of the remote hostname from where we connected if known"
-  (declare (special emacspeak-remote-hostname))
+  (cl-declare (special emacspeak-remote-hostname))
   (when (file-exists-p   emacspeak-remote-hostname)
     (let ((buffer (find-file-noselect emacspeak-remote-hostname))
           (result nil))
@@ -156,9 +157,9 @@ Uses value returned by `emacspeak-remote-get-current-remote-hostname'."
        fields host port user)
     (setq fields (split-string spec "[@:]"))
     (setq
-     user  (first fields)
-     host (second fields)
-     port (third fields))
+     user  (cl-first fields)
+     host (cl-second fields)
+     port (cl-third fields))
     (ssh
      (format "%s -p %s -l %s"
              host port user)
@@ -196,7 +197,7 @@ Uses value returned by `emacspeak-remote-get-current-remote-hostname'."
   "Connect via ssh to remote Emacspeak server.
 Server is specified via custom option `emacspeak-remote-default-ssh-server'."
   (interactive)
-  (declare (special emacspeak-remote-default-ssh-server))
+  (cl-declare (special emacspeak-remote-default-ssh-server))
   (when emacspeak-remote-default-ssh-server
     (setq dtk-program emacspeak-remote-default-ssh-server)
     (dtk-select-server emacspeak-remote-default-ssh-server)
@@ -217,7 +218,7 @@ port that that host is listening on for speech requests."
                      (emacspeak-remote-get-current-remote-hostname) ;initial input
                      )
     (read-from-minibuffer "Remote port:" dtk-local-server-port)))
-  (declare (special dtk-speaker-process dtk-program 
+  (cl-declare (special dtk-speaker-process dtk-program 
                     dtk-local-server-port
                     dtk-local-engine emacspeak-eterm-remote-hosts-table))
   (let* ((dtk-program dtk-local-engine)
@@ -245,7 +246,7 @@ port that that host is listening on for speech requests."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
