@@ -47,6 +47,7 @@
 ;;}}}
 ;;{{{ requires
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 
 ;;}}}
@@ -59,7 +60,7 @@
 ;;; While enumerating a slice, ask for information about neighbours:
 ;;;
 
-(defstruct (emacspeak-table
+(cl-defstruct (emacspeak-table
             (:constructor cons-emacspeak-table))
   row-header                            ;pointer to column  0
   column-header                         ;pointer to row 0
@@ -79,7 +80,7 @@
      for element across  elements do 
      (assert (vectorp element) t "Row %s is not a vector" index)
      (aset row-h index (aref element 0)) ; build column 0
-     (incf index))
+     (cl-incf index))
     (setf (emacspeak-table-row-header table) row-h)
     (setf (emacspeak-table-current-row table) 0)
     (setf (emacspeak-table-current-column table) 0)
@@ -108,7 +109,7 @@
     (cl-loop
      for row across elements do
      (aset result index (aref row column))
-     (incf index))
+     (cl-incf index))
     result))
 
 (defun emacspeak-table-num-rows (table)
@@ -159,7 +160,7 @@ Calls callback once per column."
         (found nil))
     (cl-loop
      for   i from 0   to count
-     and column = next then (% (incf column) count)
+     and column = next then (% (cl-incf column) count)
      if
      (funcall predicate  pattern
               (emacspeak-table-this-element table  index column))
@@ -178,12 +179,12 @@ Calls callback once per column."
         (count   (emacspeak-table-num-rows table))
         (found nil))
     (cl-loop for   i from 0   to count
-          and row = next then (% (incf row) count)
-          if  (funcall predicate  pattern
-                       (emacspeak-table-this-element table  row index))
-          do (setq found t)
-          until found
-          finally return (and found row))))
+             and row = next then (% (cl-incf row) count)
+             if  (funcall predicate  pattern
+                          (emacspeak-table-this-element table  row index))
+             do (setq found t)
+             until found
+             finally return (and found row))))
 
 ;;}}}
 ;;{{{  Moving point:
@@ -259,7 +260,7 @@ Calls callback once per column."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
