@@ -46,6 +46,7 @@
 ;;}}}
 ;;{{{  Required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'tetris "tetris" 'no-error)
 ;;}}}
@@ -61,7 +62,7 @@
 
 (defun emacspeak-tetris-define-pronunciations ()
   "Define speech display for tetris"
-  (declare (special emacspeak-tetris-pronunciations-defined
+  (cl-declare (special emacspeak-tetris-pronunciations-defined
                     emacspeak-pronounce-pronunciation-table emacspeak-pronounce-dictionaries-loaded))
   (require 'emacspeak-pronounce)
   (unless emacspeak-tetris-pronunciations-defined
@@ -98,11 +99,11 @@
 (aset emacspeak-tetris-shape-name-table 6 " inverted t ")
 (aset emacspeak-tetris-shape-name-table 7 " line ")
 (defun emacspeak-tetris-blank-row ()
-  (declare (special tetris-width))
+  (cl-declare (special tetris-width))
   (make-string tetris-width  0))
 
 (defun emacspeak-tetris-shape-name (tile)
-  (declare (special emacspeak-tetris-shape-name-table))
+  (cl-declare (special emacspeak-tetris-shape-name-table))
   (aref emacspeak-tetris-shape-name-table tile))
 
 ;;}}}
@@ -111,7 +112,7 @@
 ;;;bottom)
 
 (defun emacspeak-tetris-get-current-row ()
-  (declare (special tetris-border))
+  (cl-declare (special tetris-border))
   (save-excursion
     (beginning-of-line)
     (let ((start nil))
@@ -133,7 +134,7 @@
 (defun emacspeak-tetris-speak-x-coordinate ()
   "Speak current position"
   (interactive)
-  (declare  (special tetris-pos-x
+  (cl-declare  (special tetris-pos-x
                      tetris-shape))
   (message "%s at %s"
            (emacspeak-tetris-shape-name (1+ tetris-shape))
@@ -142,7 +143,7 @@
 (defun emacspeak-tetris-speak-coordinates ()
   "Speak current position"
   (interactive)
-  (declare  (special tetris-pos-x tetris-pos-y
+  (cl-declare  (special tetris-pos-x tetris-pos-y
                      tetris-shape))
   (message "%s at %s %s"
            (emacspeak-tetris-shape-name (1+ tetris-shape))
@@ -151,7 +152,7 @@
 (defun emacspeak-tetris-speak-current-shape ()
   "Speak current shape"
   (interactive)
-  (declare (special tetris-shape tetris-rot
+  (cl-declare (special tetris-shape tetris-rot
                     tetris-next-shape
                     tetris-n-rows emacspeak-tetris-filled-a-row))
   (dtk-speak
@@ -168,7 +169,7 @@
 (defun emacspeak-tetris-speak-next-shape ()
   "Speak next shape"
   (interactive)
-  (declare (special tetris-next-shape))
+  (cl-declare (special tetris-next-shape))
   (dtk-speak
    (format "%s "
            (emacspeak-tetris-shape-name (1+ tetris-next-shape)))))
@@ -176,7 +177,7 @@
 (defun emacspeak-tetris-speak-current-shape-and-coordinates ()
   "Speak shape orientation and coordinates"
   (interactive)
-  (declare (special  tetris-pos-x tetris-pos-y
+  (cl-declare (special  tetris-pos-x tetris-pos-y
                      tetris-shape tetris-rot))
   (message "%s at %s %s  at rotation %s"
            (emacspeak-tetris-shape-name (1+ tetris-shape))
@@ -187,7 +188,7 @@
 (defun emacspeak-tetris-speak-score()
   "Speak the score"
   (interactive)
-  (declare (special tetris-n-shapes tetris-n-rows
+  (cl-declare (special tetris-n-shapes tetris-n-rows
                     tetris-score
                     tetris-width))
   (dtk-speak
@@ -208,7 +209,7 @@
 going on. Reduce it as you get better.")
 
 (defun emacspeak-tetris-tick-period ()
-  (declare (special emacspeak-tetris-tick-period))
+  (cl-declare (special emacspeak-tetris-tick-period))
   emacspeak-tetris-tick-period)
 
 (defalias 'tetris-get-tick-period 'emacspeak-tetris-tick-period)
@@ -328,7 +329,7 @@ compensate for the difference between aural and visual
 interaction.  Despite the clock being slowed down, playing
 Tetris with speech feedback alone requires a lot of
 concentration and the game is a good mental challenge. "
-  (declare (special tetris-tick-period
+  (cl-declare (special tetris-tick-period
                     emacspeak-tetris-blank-row))
   (when (ems-interactive-p)
     (setq tetris-tick-period emacspeak-tetris-tick-period)
@@ -345,7 +346,7 @@ concentration and the game is a good mental challenge. "
 
 (defadvice tetris-start-game (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (declare (special emacspeak-tetris-blank-row))
+  (cl-declare (special emacspeak-tetris-blank-row))
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (setq tetris-width emacspeak-tetris-width)
@@ -412,7 +413,8 @@ concentration and the game is a good mental challenge. "
 
 (defadvice tetris-draw-score (around emacspeak pre act comp)
   "dont draw the score"
-  nil)
+  (when nil ad-do-it) ; to silence byte-compiler 
+)
 ;;}}}
 ;;{{{  speak line 
 
@@ -421,16 +423,16 @@ concentration and the game is a good mental challenge. "
 
 (defun emacspeak-tetris-define-keys ()
   "Setup emacspeak tetris key bindings "
-  (declare (special tetris-mode-map))
+  (cl-declare (special tetris-mode-map))
   (define-key tetris-mode-map "v" 'emacspeak-tetris-speak-column)
   (define-key tetris-mode-map "n" 'emacspeak-self-insert-command)
   (define-key tetris-mode-map "N" 'tetris-start-game)
   (define-key  tetris-mode-map "c" 'emacspeak-tetris-speak-row)
   (cl-loop for i from 0 to 9
-        do
-        (define-key tetris-mode-map
-          (format "%s" i)
-          'tetris-move-to-x-pos))
+           do
+           (define-key tetris-mode-map
+             (format "%s" i)
+             'tetris-move-to-x-pos))
   (define-key tetris-mode-map "a" 'tetris-move-left-edge)
   (define-key tetris-mode-map "e" 'tetris-move-right-edge)
   (define-key tetris-mode-map "l" 'tetris-move-right)
@@ -453,7 +455,7 @@ concentration and the game is a good mental challenge. "
 (defun emacspeak-tetris-goto-bottom-row ()
   "Move to and speak bottom row"
   (interactive)
-  (declare (special tetris-height))
+  (cl-declare (special tetris-height))
   (goto-line
    (1+ tetris-height))
   (emacspeak-tetris-speak-row))
@@ -465,7 +467,7 @@ concentration and the game is a good mental challenge. "
 (defun emacspeak-tetris-goto-top-row ()
   "Move to and speak the top row"
   (interactive)
-  (declare (special tetris-height
+  (cl-declare (special tetris-height
                     emacspeak-tetris-blank-row))
   (goto-line tetris-height)
   (search-backward emacspeak-tetris-blank-row  nil t)
@@ -475,7 +477,7 @@ concentration and the game is a good mental challenge. "
 (defun tetris-move-left-edge ()
   "Moves the shape to the left edge  of the playing area"
   (interactive)
-  (declare (special tetris-pos-x tetris-width))
+  (cl-declare (special tetris-pos-x tetris-width))
   (let ((hit nil))
     (tetris-erase-shape)
     (while(and (> tetris-pos-x 0)
@@ -487,7 +489,7 @@ concentration and the game is a good mental challenge. "
 (defun tetris-move-right-edge ()
   "Moves the shape to the right edge  of the playing area"
   (interactive)
-  (declare (special tetris-pos-x tetris-width))
+  (cl-declare (special tetris-pos-x tetris-width))
   (let ((hit nil)
         (max(- tetris-width (tetris-shape-width))))
     (tetris-erase-shape)
@@ -500,7 +502,7 @@ concentration and the game is a good mental challenge. "
 (defun tetris-move-to-x-pos ()
   "Moves the shape to a specified x position if possible"
   (interactive)
-  (declare (special tetris-pos-x tetris-width))
+  (cl-declare (special tetris-pos-x tetris-width))
   (let ((hit nil)
         (x
          (condition-case nil
@@ -524,7 +526,7 @@ concentration and the game is a good mental challenge. "
                  (not hit))
         (setq tetris-pos-x (1- tetris-pos-x))
         (setq hit (tetris-test-shape))
-        (incf diff))))
+        (cl-incf diff))))
     (tetris-draw-shape)))
 
 ;;}}}
@@ -532,20 +534,20 @@ concentration and the game is a good mental challenge. "
 
 (defun emacspeak-tetris-get-column-contents (x)
   "Return column contents as a string"
-  (declare (special tetris-height tetris-top-left-y
+  (cl-declare (special tetris-height tetris-top-left-y
                     tetris-top-left-x))
   (let ((result nil))
     (setq x (+ tetris-top-left-x x))
     (setq result
           (cl-loop for y from tetris-top-left-y
-                to (+ tetris-height tetris-top-left-y)
-                collect (gamegrid-get-cell x y)))
+                   to (+ tetris-height tetris-top-left-y)
+                   collect (gamegrid-get-cell x y)))
     (mapconcat 'char-to-string result "")))
 
 (defun emacspeak-tetris-speak-column (&optional x)
   "Speak  column --default is to speak current column"
   (interactive "p")
-  (declare (special tetris-pos-x))
+  (cl-declare (special tetris-pos-x))
   (or  x (setq x tetris-pos-x))
   (dtk-speak (emacspeak-tetris-get-column-contents x)))
 
@@ -563,7 +565,7 @@ concentration and the game is a good mental challenge. "
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end: 
 
 ;;}}}
