@@ -79,8 +79,8 @@
 ;;}}}
 ;;{{{  Required modules
 
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'sox-gen)
 
@@ -92,7 +92,7 @@
 
 (defun emacspeak-threes-get-rows-max ()
   "Return max for each row."
-  (declare (special threes-cells))
+  (cl-declare (special threes-cells))
   (mapcar #'(lambda (r) (apply #'max   r)) threes-cells))
 
 ;;}}}
@@ -104,7 +104,7 @@
   `(defun  ,(intern  (format "emacspeak-threes-%s" i)) ()
      "Set next tile."
      (interactive)
-     (declare (special threes-next-number))
+     (cl-declare (special threes-next-number))
      (setq threes-next-number ,i)
      (emacspeak-threes-speak-board))))
 
@@ -113,8 +113,8 @@
   (let ((fade "fade h .1 .5 .4 gain -8 "))
     (cond
      ((= 1 number) (sox-sin .5 "%-2:%-1"fade))
-     ((= 2 number) (sox-sin .5 "%1:%2" fade))
-     ((= 3 number) (sox-sin .5 "%4:%5"fade)))))
+     ((= 2 number) (sox-sin .5 "%1:%3" fade))
+     ((= 3 number) (sox-sin .5 "%4:%6"fade)))))
 
 ;;}}}
 ;;{{{ Advice interactive commands:
@@ -122,15 +122,15 @@
 (defun emacspeak-threes-speak-board ()
   "Speak the board."
   (interactive)
-  (declare (special threes-cells threes-next-number
+  (cl-declare (special threes-cells threes-next-number
                     emacspeak-threes-rows-max))
   (emacspeak-threes-sox-gen threes-next-number)
   (let ((cells (copy-sequence threes-cells)))
     (nconc
      cells
      (list (propertize (format "%s" threes-next-number) 'personality voice-bolden)))
-    (tts-with-punctuations 'some (dtk-speak-list   cells))
-    (emacspeak-auditory-icon 'complete)
+     (dtk-speak-list   cells)
+    (emacspeak-auditory-icon 'select-object)
     (unless  (equal (emacspeak-threes-get-rows-max) emacspeak-threes-rows-max)
       (emacspeak-auditory-icon 'item))))
 
@@ -143,15 +143,13 @@
 (defun emacspeak-threes-speak-transposed-board ()
   "Speak the board by columns."
   (interactive)
-  (declare (special threes-cells))
-  (tts-with-punctuations
-   'some
-   (dtk-speak-list   (threes-cells-transpose threes-cells) 4))
+  (cl-declare (special threes-cells))
+   (dtk-speak-list   (threes-cells-transpose threes-cells) 4)
   (emacspeak-auditory-icon 'progress))
 
 (defun emacspeak-threes-setup ()
   "Set up additional key-bindings."
-  (declare (special threes-mode-map))
+  (cl-declare (special threes-mode-map))
   (define-key threes-mode-map "1" 'emacspeak-threes-1)
   (define-key threes-mode-map "2" 'emacspeak-threes-2)
   (define-key threes-mode-map "3" 'emacspeak-threes-3)
@@ -204,7 +202,7 @@
 ;;}}}
 ;;{{{ Push And Pop states:
 
-(defstruct emacspeak-threes-game-state
+(cl-defstruct emacspeak-threes-game-state
   board)
 
 (defvar emacspeak-threes-game-stack nil
@@ -213,7 +211,7 @@
 (defun emacspeak-threes-push-state ()
   "Push current game state on stack."
   (interactive)
-  (declare (special emacspeak-threes-game-stack threes-cells))
+  (cl-declare (special emacspeak-threes-game-stack threes-cells))
   (push
    (make-emacspeak-threes-game-state
     :board (copy-sequence threes-cells))
@@ -224,7 +222,7 @@
 (defun emacspeak-threes-pop-state ()
   "Reset state from stack."
   (interactive)
-  (declare (special emacspeak-threes-game-stack threes-cells
+  (cl-declare (special emacspeak-threes-game-stack threes-cells
                     threes-game-over-p))
   (cond
    ((null emacspeak-threes-game-stack) (error "No saved  states."))
@@ -246,7 +244,7 @@
          (format "Stack: %s New? "
                  (length emacspeak-threes-game-stack))
          (/ (length emacspeak-threes-game-stack) 2))))))
-  (declare (special emacspeak-threes-game-stack))
+  (cl-declare (special emacspeak-threes-game-stack))
   (setq emacspeak-threes-game-stack
         (butlast emacspeak-threes-game-stack
                  (- (length emacspeak-threes-game-stack) drop)))
@@ -267,7 +265,7 @@
 Optional interactive prefix arg prompts for a file.
 Note that the file is overwritten silently."
   (interactive "P")
-  (declare (special emacspeak-threes-game-file emacspeak-threes-game-stack))
+  (cl-declare (special emacspeak-threes-game-file emacspeak-threes-game-stack))
   (with-temp-buffer
     (let ((file
            (if prompt
