@@ -55,6 +55,7 @@
 ;;}}}
 ;;{{{ required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'emacspeak-webutils)
 (require 'gweb)
@@ -66,7 +67,7 @@
 ;;}}}
 ;;{{{ structures
 
-(defstruct (emacspeak-url-template
+(cl-defstruct (emacspeak-url-template
             (:constructor emacspeak-url-template-constructor))
   name ;Human-readable name
   template ;template URL string
@@ -106,13 +107,13 @@
 
 (defun emacspeak-url-template-set (key ut)
   "Add specified template to key. "
-  (declare (special emacspeak-url-template-table))
+  (cl-declare (special emacspeak-url-template-table))
   (setf (gethash key emacspeak-url-template-table) ut))
 
 ;;;###autoload
 (defun emacspeak-url-template-get (key)
   "Lookup key and return corresponding template. "
-  (declare (special emacspeak-url-template-table))
+  (cl-declare (special emacspeak-url-template-table))
   (gethash key emacspeak-url-template-table))
 
 ;;}}}
@@ -138,7 +139,7 @@ fetcher Unless specified, browse-url retrieves URL.
  that is called with the URI to retrieve.
 documentation Documents this template resource.
 dont-url-encode if true then url arguments are not url-encoded "
-  (declare (special emacspeak-url-template-table))
+  (cl-declare (special emacspeak-url-template-table))
   (emacspeak-url-template-set
    name
    (emacspeak-url-template-constructor
@@ -169,7 +170,7 @@ dont-url-encode if true then url arguments are not url-encoded "
   (interactive
    (list
     (read-file-name "Save URL templates to: " emacspeak-resource-directory)))
-  (declare (special emacspeak-resource-directory))
+  (cl-declare (special emacspeak-resource-directory))
   (let ((print-level nil)
         (print-length nil)
         (buffer (find-file-noselect
@@ -246,7 +247,7 @@ dont-url-encode if true then url arguments are not url-encoded "
 
 (defun emacspeak-url-template-iplayer-player (cid)
   "Take a cid particle, and opens player page."
-  (declare (special emacspeak-url-template-iplayer-converter))
+  (cl-declare (special emacspeak-url-template-iplayer-converter))
   (add-hook
    'emacspeak-web-post-process-hook
    #'(lambda nil
@@ -273,7 +274,7 @@ dont-url-encode if true then url arguments are not url-encoded "
          (t (concat outlet "/")))))
   'emacspeak-speak-read-date-year/month/date)
  #'(lambda ()
-     (declare (special emacspeak-we-url-executor))
+     (cl-declare (special emacspeak-we-url-executor))
      (setq emacspeak-we-url-executor
            'emacspeak-url-template-iplayer-player))
  "BBC iPlayer"
@@ -288,7 +289,7 @@ dont-url-encode if true then url arguments are not url-encoded "
  "http://www.bbc.co.uk/radio/programmes/genres/%s/schedules.xml"
  (list "Genre/Genre/Genre: ")
  #'(lambda ()
-     (declare (special emacspeak-we-url-executor))
+     (cl-declare (special emacspeak-we-url-executor))
      (setq emacspeak-we-url-executor 'emacspeak-url-template-iplayer-player))
  "BBC iPlayer Genre"
  #'(lambda (url)
@@ -297,9 +298,25 @@ dont-url-encode if true then url arguments are not url-encoded "
       (emacspeak-xslt-get "bbc-iplayer.xsl") url))
  'dont-url-encode)
 
+;;}}}
+;;{{{ Guardian Feed Directory:
+(emacspeak-url-template-define
+ "Guardian RSS Feeds Directory"
+ "http://rss2.io/lists/guardian.opml"
+ nil nil
+ "Guardian Feeds  Directory"
+ #'emacspeak-feeds-opml-display)
+
 ;;}}}
 ;;{{{ bbc
 
+(emacspeak-url-template-define
+ "BBC World News Summary"
+ "http://opml.radiotime.com/Tune.ashx?c=pbrowse&id=p193595"
+ nil nil
+ "BBC World News Summary"
+ #'emacspeak-feeds-opml-display)
+
 (emacspeak-url-template-define
  "BBC Program Guide"
  "http://downloads.bbc.co.uk/podcasts/ppg.xml"
@@ -373,7 +390,7 @@ dont-url-encode if true then url arguments are not url-encoded "
 
 (defun emacspeak-url-template-setup-content-filter ()
   "Set up content filter in displayed page."
-  (declare (special emacspeak-we-xpath-filter emacspeak-we-paragraphs-xpath-filter))
+  (cl-declare (special emacspeak-we-xpath-filter emacspeak-we-paragraphs-xpath-filter))
   (setq emacspeak-we-xpath-filter emacspeak-we-paragraphs-xpath-filter))
 
 ;;}}}
@@ -539,15 +556,14 @@ from English to German")
 
 (emacspeak-url-template-define
  "NY Times Mobile"
- "http://mobile.nytimes.com"
+ "https://mobile.nytimes.com"
  nil
  #'(lambda ()
      (emacspeak-url-template-setup-content-filter)
      (emacspeak-speak-buffer))
  "NYTimes Mobile Site"
  #'(lambda (url)
-     (emacspeak-we-extract-by-role "main" url))
- )
+     (emacspeak-we-xslt-filter "//article" url)))
 
 ;;}}}
 ;;{{{ google OverviewOfNews
@@ -569,7 +585,7 @@ from English to German")
 (emacspeak-url-template-define
  "html Google News Search"
  "https://news.google.com/news?hl=en&ned=tus&q=%s&btnG=Google+Search"
- (list "Google News: ")
+ (list #'gweb-news-autocomplete)
  #'(lambda ()
      (emacspeak-url-template-setup-content-filter)
      (emacspeak-speak-rest-of-buffer))
@@ -577,7 +593,7 @@ from English to German")
 
 (defun emacspeak-url-template-google-atom-news-display (feed-url)
   "View Google Atom news feed pulled using Curl."
-  (declare (special g-atom-view-xsl
+  (cl-declare (special g-atom-view-xsl
                     g-curl-program g-curl-common-options))
   (emacspeak-webutils-autospeak)
   (g-display-result
@@ -589,7 +605,7 @@ from English to German")
 (emacspeak-url-template-define
  "Google News Search"
  "https://news.google.com/news?hl=en&ned=tus&q=%s&btnG=Google+Search&output=atom"
- (list "Google News: ")
+ (list #'gweb-news-autocomplete)
  nil
  "Search Google news."
  #'emacspeak-url-template-google-atom-news-display)
@@ -629,7 +645,7 @@ from English to German")
  (list
   #'(lambda ()
       (read-from-minibuffer "City/Zip: "
-                            (bound-and-true-p gweb-my-postal-code))))
+                            (bound-and-true-p gweb-my-zip))))
  nil
  "Google News By Region."
  #'emacspeak-url-template-google-atom-news-display)
@@ -844,7 +860,7 @@ name of the list.")
 
 ;;}}}
 ;;{{{ MLB scores
-
+(declare-function emacspeak-wizards-mlb-standings  nil "emacspeak-wizards")
 ;;; standings:
 
 (emacspeak-url-template-define
@@ -863,9 +879,9 @@ name of the list.")
         (setq result
               (format
                "year_%s/month_%s/day_%s"
-               (first fields)
-               (second fields)
-               (third fields)))
+               (cl-first fields)
+               (cl-second fields)
+               (cl-third fields)))
         result))
   )
  'emacspeak-speak-buffer
@@ -899,9 +915,9 @@ name of the list.")
         (setq result
               (format
                "year_%s/month_%s/day_%s/"
-               (first fields)
-               (second fields)
-               (third fields)))
+               (cl-first fields)
+               (cl-second fields)
+               (cl-third fields)))
         result)))
  nil
  "Display baseball Play By Play."
@@ -922,12 +938,12 @@ name of the list.")
         (setq result
               (format
                "year_%s/month_%s/day_%s/gid_%s_%s_%s"
-               (first fields)
-               (second fields)
-               (third fields)
-               (first fields)
-               (second fields)
-               (third fields)))
+               (cl-first fields)
+               (cl-second fields)
+               (cl-third fields)
+               (cl-first fields)
+               (cl-second fields)
+               (cl-third fields)))
         result))
   "Visiting Team: "
   "Home Team: ")
@@ -953,12 +969,12 @@ name of the list.")
         (setq result
               (format
                "year_%s/month_%s/day_%s/gid_%s_%s_%s"
-               (first fields)
-               (second fields)
-               (third fields)
-               (first fields)
-               (second fields)
-               (third fields)))
+               (cl-first fields)
+               (cl-second fields)
+               (cl-third fields)
+               (cl-first fields)
+               (cl-second fields)
+               (cl-third fields)))
         result))
   "Visiting Team: "
   "Home Team: ")
@@ -993,12 +1009,12 @@ JSON is retrieved from `url'."
         (setq result
               (format
                "year_%s/month_%s/day_%s/gid_%s_%s_%s"
-               (first fields)
-               (second fields)
-               (third fields)
-               (first fields)
-               (second fields)
-               (third fields)))
+               (cl-first fields)
+               (cl-second fields)
+               (cl-third fields)
+               (cl-first fields)
+               (cl-second fields)
+               (cl-third fields)))
         result))
   "Visiting Team: "
   "Home Team: ")
@@ -1021,12 +1037,12 @@ JSON is retrieved from `url'."
         (setq result
               (format
                "year_%s/month_%s/day_%s/gid_%s_%s_%s"
-               (first fields)
-               (second fields)
-               (third fields)
-               (first fields)
-               (second fields)
-               (third fields)))
+               (cl-first fields)
+               (cl-second fields)
+               (cl-third fields)
+               (cl-first fields)
+               (cl-second fields)
+               (cl-third fields)))
         result))
   "Visiting Team: "
   "Home Team: ")
@@ -1036,7 +1052,7 @@ JSON is retrieved from `url'."
 
 ;;}}}
 ;;{{{ NBA Standings:
-
+(declare-function emacspeak-wizards-nba-standings  nil "emacspeak-wizards")
 (emacspeak-url-template-define
  "NBA  standings"
  "http://www.nba.com/NASApp/nba/nba/standings/index.jsp" ;;; dummy
@@ -1070,7 +1086,7 @@ JSON is retrieved from `url'."
  "http://www.timesofindia.com"
  nil
  #'(lambda ()
-     (declare (special emacspeak-we-url-rewrite-rule))
+     (cl-declare (special emacspeak-we-url-rewrite-rule))
      (setq emacspeak-we-url-rewrite-rule
            (list "$" "&prtPage=1")))
  "Retrieve Times Of India.
@@ -1081,15 +1097,6 @@ Set up URL rewrite rule to get print page."
 
 ;;}}}
 ;;{{{ weather underground
-(emacspeak-url-template-define
- "Lightweight  weather from wunderground"
- "https://braille.wunderground.com/cgi-bin/findweather/hdfForecast?brand=braille&query=%s"
- (list
-  #'(lambda nil
-      (read-from-minibuffer "State/City:"
-                            (bound-and-true-p  gweb-my-postal-code))))
- #'emacspeak-speak-buffer
- "Pull light-weight weather feed for specified state/city.")
 
 (emacspeak-url-template-define
  "rss weather from wunderground"
@@ -1097,17 +1104,28 @@ Set up URL rewrite rule to get print page."
  (list
   #'(lambda nil
       (read-from-minibuffer "State/City:"
-                            (bound-and-true-p  gweb-my-postal-code))))
+                            (bound-and-true-p  gweb-my-zip))))
  nil
  "Pull RSS weather feed for specified state/city."
  #'emacspeak-feeds-rss-display)
 
+(emacspeak-url-template-define
+ "Weather Light From Wunderground"
+ "https://braille.wunderground.com/cgi-bin/findweather/hdfForecast?brand=braille&query=%s"
+ (list
+  #'(lambda nil
+      (read-from-minibuffer "State/City:"
+                            (bound-and-true-p  gweb-my-zip))))
+ #'emacspeak-speak-buffer
+ "Light weight weather forecast"
+ #'browse-url)
+
 (emacspeak-url-template-define
  "Weather forecast from Weather Underground"
  "http://mobile.wunderground.com/cgi-bin/findweather/getForecast?query=%s"
  (list
   #'(lambda () (read-from-minibuffer "Zip: "
-                                     (bound-and-true-p  gweb-my-postal-code))))
+                                     (bound-and-true-p  gweb-my-zip))))
  'emacspeak-speak-buffer
  "Weather forecast from weather underground mobile."
  )
@@ -1219,7 +1237,7 @@ Query can include filters such as:
 <term>: Query Term.
 extension:<ext> Filter by file extension
 -filename:<pattern> Filter out files matching pattern.")
-
+(declare-function emacspeak-eww-next-h (&optional speak) "emacspeak-eww")
 (emacspeak-url-template-define
  "GitHub Search"
  "https://github.com/search?q=%s"
@@ -1328,7 +1346,7 @@ extension:<ext> Filter by file extension
 ;;;###autoload
 (defun emacspeak-url-template-open (ut)
   "Fetch resource identified by URL template."
-  (declare (special emacspeak-web-post-process-hook))
+  (cl-declare (special emacspeak-web-post-process-hook))
   (let ((fetcher (or (emacspeak-url-template-fetcher ut) 'browse-url))
         (url (emacspeak-url-template-url ut))
         (action (emacspeak-url-template-post-action ut)))
@@ -1355,9 +1373,9 @@ extension:<ext> Filter by file extension
   "Generate a setter that sets emacspeak-eww-url-template
 to specified name for use as a callback."
   (eval
-    `#'(lambda ()
-       (declare (special emacspeak-eww-url-template))
-       (setq emacspeak-eww-url-template ',name))))
+   `#'(lambda ()
+        (cl-declare (special emacspeak-eww-url-template))
+        (setq emacspeak-eww-url-template ',name))))
 
 ;;;###autoload
 (defun emacspeak-url-template-fetch (&optional documentation)
@@ -1387,7 +1405,7 @@ Optional interactive prefix arg displays documentation for specified resource."
 Use Emacs completion to obtain a list of available
 resources."
   (interactive)
-  (declare (special emacspeak-url-template-table))
+  (cl-declare (special emacspeak-url-template-table))
   (let ((completion-ignore-case t)
         (name nil))
     (setq name
@@ -1400,7 +1418,7 @@ resources."
 
 (defun emacspeak-url-template-generate-texinfo-documentation (buffer)
   "Generates texinfo section documenting all defined URL templates."
-  (declare (special emacspeak-url-template-table))
+  (cl-declare (special emacspeak-url-template-table))
   (with-current-buffer buffer
     (insert
      "@node URL Templates \n@section URL Templates\n\n")
@@ -1466,6 +1484,20 @@ prompts for a location and speaks the forecast. \n\n"
  #'emacspeak-speak-mode-line
  "Search NLS Bard Catalog. Login once before using this template.")
 
+(emacspeak-url-template-define
+ "NLS Bard Popular"
+"https://nlsbard.loc.gov:443/nlsbardprod/search/most_popular/page/1/sort/s/srch/most_popular/local/0"
+ nil
+ #'emacspeak-speak-mode-line
+ "NLS Bard Catalog: Most Popular. Login once before using this template.")
+
+(emacspeak-url-template-define
+ "NLS Bard Recent"
+ "https://nlsbard.loc.gov/mainpage/srch_recentlyadded"
+ nil
+ #'emacspeak-speak-mode-line
+ "NLS Bard Catalog: Recently Added. Login once before using this template.")
+
 ;;}}}
 ;;{{{ Bloomberg:
 (emacspeak-url-template-define
@@ -1493,17 +1525,33 @@ prompts for a location and speaks the forecast. \n\n"
       (let* ((code (read-from-minibuffer "Flight Number: "))
              (fields (split-string code)))
         (format "airline=%s&flightNumber=%s"
-                (first fields) (second fields)))))
+                (cl-first fields) (cl-second fields)))))
  nil
  "Flight Tracker")
 
+;;}}}
+;;{{{ Washington Post
+
+(emacspeak-url-template-define
+ "Washington Post"
+ "https://www.washingtonpost.com/"
+ nil nil
+ "Washington Post Contents"
+ #'(lambda (url)
+     (emacspeak-we-extract-by-class-list 
+'("headline xx-small highlight-style bulleted text-align-inherit " "headline normal normal-style text-align-inherit "
+  "no-skin flex-item flex-stack normal-air text-align-left wrap-text equalize-height-target"
+  "headline " "blurb normal normal-style ")
+url
+'speak)))
+
 ;;}}}
 (provide 'emacspeak-url-template)
 ;;{{{ end of file
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
