@@ -47,8 +47,28 @@
 ;;; Code:
 ;;}}}
 ;;{{{ requires
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require  'vm "vm" 'no-error)
+;;}}}
+;;{{{ Forward Decls:
+
+(declare-function vm-from-of (msg) "vm-message")
+(declare-function  vm-subject-of (msg) "vm-message")
+(declare-function  vm-to-of (msg) "vm-message")
+(declare-function  vm-su-full-name (msg) "vm-summary")
+(declare-function  vm-su-from (msg) "vm-summary")
+(declare-function vm-su-subject (msg) "vm-summary")
+(declare-function  vm-su-to-names (msg) "vm-summary")
+(declare-function  vm-su-to (msg) "vm-summary")
+(declare-function  vm-su-line-count (msg) "vm-summary")
+(declare-function vm-decode-mime-encoded-words-in-string (s) "vm-mime")
+(declare-function  vm-labels-of (msg) "vm-message")
+(declare-function  vm-goto-message (msg) "vm-message")
+(declare-function vm-delete-message (msg) "vm-message")
+(declare-function  u-vm-color-fontify-buffer nil "u-vm-color")
+(declare-function  u-vm-color-summary-mode (&optional arg) "u-vm-color")
+
 ;;}}}
 ;;{{{ voice locking:
 
@@ -68,7 +88,7 @@ Note that some badly formed mime messages  cause trouble."
 
 (defun emacspeak-vm-mode-setup ()
   "Setup function placed on vm-mode-hook by Emacspeak."
-  (declare (special  dtk-punctuation-mode dtk-allcaps-beep))
+  (cl-declare (special  dtk-punctuation-mode dtk-allcaps-beep))
   (setq dtk-punctuation-mode 'all)
   (when dtk-allcaps-beep
     (dtk-toggle-allcaps-beep)))
@@ -119,28 +139,29 @@ Note that some badly formed mime messages  cause trouble."
 
 (defvar emacspeak-vm-user-login-name  (user-login-name)
   "Login name of this user")
-s(defun emacspeak-vm-yank-header ()
-   "Yank specified header into kill ring."
-   (interactive)
-   (declare (special vm-message-pointer))
-   (cond
-    (vm-message-pointer
-     (dtk-stop)
-     (let*  ((message (car vm-message-pointer))
-             (from (vm-from-of message))
-             (subject (vm-subject-of  message))
-             (to (vm-to-of message))
-             (header nil))
-       (while (not header)
-         (setq header
-               (case
-                   (read-char "f From s Subject t To")
-                 (?s subject)
-                 (?f from)
-                 (?t to))))
-       (kill-new header)
-       (message "%s" header)))
-    (t (error "No current message."))))
+(defun emacspeak-vm-yank-header ()
+  "Yank specified header into kill ring."
+  (interactive)
+  (cl-declare (special vm-message-pointer))
+  (cond
+   (vm-message-pointer
+    (dtk-stop)
+    (let*  ((message (car vm-message-pointer))
+            (from (vm-from-of message))
+            (subject (vm-subject-of  message))
+            (to (vm-to-of message))
+            (url  (browse-url-url-at-point))
+            (header nil))
+      (while (not header)
+        (setq header
+              (case (read-char "f From s Subject t To u URL")
+                (?s subject)
+                (?f from)
+                (?u url)
+                (?t to))))
+      (when header (kill-new header))
+      (message "%s" header)))
+   (t (error "No current message."))))
 
 (defcustom emacspeak-vm-headers-strip-octals t
   "Specify whether non-ascii chars should be stripped when
@@ -160,7 +181,7 @@ s(defun emacspeak-vm-yank-header ()
 
 (defun emacspeak-vm-summarize-message ()
   "Summarize the current vm message. "
-  (declare (special vm-message-pointer smtpmail-local-domain
+  (cl-declare (special vm-message-pointer smtpmail-local-domain
                     vm-presentation-buffer  emacspeak-vm-headers-strip-octals))
   (when vm-message-pointer
     (let*  ((message (car vm-message-pointer))
@@ -204,7 +225,7 @@ s(defun emacspeak-vm-yank-header ()
 (defun emacspeak-vm-speak-labels ()
   "Speak a message's labels"
   (interactive)
-  (declare (special vm-message-pointer))
+  (cl-declare (special vm-message-pointer))
   (when vm-message-pointer
     (message "Labels: %s"
              (vm-labels-of (car vm-message-pointer)))))
@@ -212,12 +233,10 @@ s(defun emacspeak-vm-yank-header ()
 (defun emacspeak-vm-mode-line ()
   "VM mode line information. "
   (interactive)
-  (declare (special vm-ml-message-attributes-alist
+  (cl-declare (special vm-ml-message-attributes-alist
                     vm-ml-message-read vm-ml-message-unread
                     vm-virtual-folder-definition vm-ml-message-new
                     vm-ml-message-number vm-ml-highest-message-number))
-  (when (buffer-modified-p)
-    (emacspeak-auditory-icon 'modified-object))
   (cond
    (vm-virtual-folder-definition
     (dtk-speak
@@ -372,7 +391,7 @@ Then speak the screenful. "
 (defun emacspeak-vm-catch-up-all-messages ()
   "Mark all messages in folder to be deleted. Use with caution."
   (interactive)
-  (declare (special vm-ml-highest-message-number))
+  (cl-declare (special vm-ml-highest-message-number))
   (vm-goto-message 1)
   (vm-delete-message
    (read vm-ml-highest-message-number))
@@ -382,7 +401,7 @@ Then speak the screenful. "
 ;;}}}
 ;;{{{  Keybindings:
 (when (boundp 'vm-mode-map)
-  (declaim  (special
+  (cl-declaim  (special
              vm-mode-map
              global-map emacspeak-prefix emacspeak-keymap))
   (define-key vm-mode-map "\M-\C-m" 'widget-button-press)
@@ -405,7 +424,7 @@ Then speak the screenful. "
 ;;{{{ advise searching:
 (defadvice vm-isearch-forward (around emacspeak pre act comp)
   "Provide auditory feedback"
-  (declare (special vm-message-pointer))
+  (cl-declare (special vm-message-pointer))
   (cond
    ((ems-interactive-p)
     (let ((orig (point)))
@@ -420,7 +439,7 @@ Then speak the screenful. "
 
 (defadvice vm-isearch-backward (around emacspeak pre act comp)
   "Provide auditory feedback"
-  (declare (special vm-message-pointer))
+  (cl-declare (special vm-message-pointer))
   (cond
    ((ems-interactive-p)
     (let ((orig (point)))
@@ -483,7 +502,7 @@ Leave point at front of decoded attachment."
           #'(lambda nil
               (emacspeak-pronounce-refresh-pronunciations)))
 
-(declaim (special emacspeak-pronounce-internet-smileys-pronunciations))
+(cl-declaim (special emacspeak-pronounce-internet-smileys-pronunciations))
 (cl-loop
  for hook in
  '(mail-mode-hook vm-presentation-mode-hook)
@@ -555,7 +574,7 @@ If N is negative, move backward instead."
       (when
           (or (get-text-property (point) 'intangible)
               (get-text-property (point) 'cursorintangible))
-        (incf n))
+        (cl-incf n))
       (decf n))
     (unless (zerop n)
       (message  "No more buttons"))
@@ -603,20 +622,20 @@ If N is negative, move backward instead."
   :group 'emacspeak-vm)
 (defvar emacspeak-vm-demote-html-attachments
   '(
-        favorite-internal  "text/plain" "text/enriched"
-        "text/html" "application/xml+xhtml")
+    favorite-internal  "text/plain" "text/enriched"
+    "text/html" "application/xml+xhtml")
   "Setting that prefers text/plain alternatives over html/xhtml.")
 
 (defvar emacspeak-vm-promote-html-attachments
   '(
-        favorite-internal   "text/html" "application/xml+xhtml"
-        "text/plain" "text/enriched")
+    favorite-internal   "text/html" "application/xml+xhtml"
+    "text/plain" "text/enriched")
   "Setting that prefers  alternatives  html/xhtml over text/plain.")
 
 (defun emacspeak-vm-use-raman-settings ()
   "Customization settings for VM used by the author of
 Emacspeak."
-  (declare (special emacspeak-vm-demote-html-attachments
+  (cl-declare (special emacspeak-vm-demote-html-attachments
                     emacspeak-vm-promote-html-attachments
                     vm-mime-charset-converter-alist
                     vm-mime-default-face-charsets
@@ -667,7 +686,7 @@ Emacspeak."
 (defun emacspeak-vm-toggle-html-mime-demotion ()
   "Toggle state of HTML Mime Demotion."
   (interactive)
-  (declare (special emacspeak-vm-demote-html-attachments
+  (cl-declare (special emacspeak-vm-demote-html-attachments
                     emacspeak-vm-promote-html-attachments
                     vm-mime-alternative-select-method))
   (cond
@@ -728,9 +747,9 @@ text using wvText."
 
 (defun emacspeak-vm-add-mime-converter (converter)
   "Helper to add a converter specification."
-  (declare (special vm-mime-type-converter-alist))
+  (cl-declare (special vm-mime-type-converter-alist))
   (unless
-      (find-if
+      (cl-find-if
        #'(lambda  (i)
            (string-equal (car i) (car converter)))
        vm-mime-type-converter-alist)
@@ -739,7 +758,7 @@ text using wvText."
 
 (defun emacspeak-vm-customize-mime-settings ()
   "Customize VM mime settings."
-  (declare (special vm-preview-lines
+  (cl-declare (special vm-preview-lines
                     vm-infer-mime-types
                     vm-mime-decode-for-preview
                     vm-auto-decode-mime-messages
@@ -786,7 +805,7 @@ text using wvText."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
