@@ -1,24 +1,5 @@
 ;;;Auto generated
 
-;;;### (autoloads nil "g-auth" "g-auth.el" (0 0 0 0))
-;;; Generated autoloads from g-auth.el
-
-(defvar g-auth-lifetime "4 hours" "\
-Auth lifetime.")
-
-(custom-autoload 'g-auth-lifetime "g-auth" nil)
-
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "g-auth" '("g-")))
-
-;;;***
-
-;;;### (autoloads nil "g-autogen" "g-autogen.el" (0 0 0 0))
-;;; Generated autoloads from g-autogen.el
-
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "g-autogen" '("g-")))
-
-;;;***
-
 ;;;### (autoloads nil "g-load-path" "g-load-path.el" (0 0 0 0))
 ;;; Generated autoloads from g-load-path.el
 
@@ -56,6 +37,16 @@ Default is to search All Mail when not on a Group line.
 ;;;### (autoloads nil "gmaps" "gmaps.el" (0 0 0 0))
 ;;; Generated autoloads from gmaps.el
 
+(autoload 'gmaps-address-location "gmaps" "\
+Returns gmaps--location structure. Memoized to save network calls.
+
+\(fn ADDRESS)" nil nil)
+
+(autoload 'gmaps-address-geocode "gmaps" "\
+Return lat/long for a given address.
+
+\(fn ADDRESS)" nil nil)
+
 (autoload 'gmaps-geocode "gmaps" "\
 Geocode given address.
 Optional argument `raw-p' returns complete JSON  object.
@@ -68,8 +59,10 @@ Optional argument `raw-p' returns raw JSON  object.
 
 \(fn LAT-LONG &optional RAW-P)" nil nil)
 
-(defvar gweb-my-location nil "\
-Geo coordinates --- automatically set by reverse geocoding gweb-my-address")
+(defvar gweb-my-address nil "\
+Location address. Setting this updates gweb-my-location coordinates  via geocoding.")
+
+(custom-autoload 'gweb-my-address "gmaps" nil)
 
 (autoload 'gmaps "gmaps" "\
 Google Maps Interaction.
@@ -100,12 +93,6 @@ Resets client so you can start with a different userid.
 ;;;### (autoloads nil "gweb" "gweb.el" (0 0 0 0))
 ;;; Generated autoloads from gweb.el
 
-(autoload 'gweb-google-autocomplete-with-corpus "gweb" "\
-Read user input using Google Suggest for auto-completion.
-Uses specified corpus for prompting and suggest selection.
-
-\(fn CORPUS)" nil nil)
-
 (if (fboundp 'register-definition-prefixes) (register-definition-prefixes "gweb" '("gweb-")))
 
 ;;;***
@@ -114,19 +101,9 @@ Uses specified corpus for prompting and suggest selection.
 
 ;;;***
 
-;;;### (autoloads nil "g-app" "g-app.el" (0 0 0 0))
-;;; Generated autoloads from g-app.el
+;;;### (autoloads nil "g-autogen" "g-autogen.el" (0 0 0 0))
+;;; Generated autoloads from g-autogen.el
 
-(autoload 'g-app-publish "g-app" "\
-Publish current entry.
-
-\(fn)" t nil)
-
-(autoload 'g-app-view "g-app" "\
-View feed using auth credentials in auth-handle.
-
-\(fn AUTH-HANDLE FEED-URL)" t nil)
-
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "g-app" '("g-app-")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "g-autogen" '("g-")))
 
 ;;;***
