@@ -47,8 +47,9 @@
 ;;{{{ required modules
 
 ;;; Code:
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
+(require 'cl-lib)
+(cl-declaim  (optimize  (safety 0) (speed 3)))
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'acss-structure)
 (require 'tts)
 
@@ -88,12 +89,12 @@ The string can set any  parameter.")
   "Define a Plain voice named NAME.
 This voice will be set   by sending the string
 COMMAND-STRING to the TTS server."
-  (declare (special plain-voice-table))
+  (cl-declare (special plain-voice-table))
   (puthash  name command-string  plain-voice-table))
 
 (defun plain-get-voice-command (name)
   "Retrieve command string for  voice NAME."
-  (declare (special plain-voice-table))
+  (cl-declare (special plain-voice-table))
   (cond
    ((listp name)
     (mapconcat #'plain-get-voice-command name " "))
@@ -102,7 +103,7 @@ COMMAND-STRING to the TTS server."
 
 (defun plain-voice-defined-p (name)
   "Check if there is a voice named NAME defined."
-  (declare (special plain-voice-table))
+  (cl-declare (special plain-voice-table))
   (gethash name plain-voice-table))
 
 ;;}}}
@@ -136,7 +137,7 @@ COMMAND-STRING to the TTS server."
 
 (defun plain-set-family-code (name code)
   "Set control code for voice family NAME  to CODE."
-  (declare (special plain-family-table))
+  (cl-declare (special plain-family-table))
   (when (stringp name) (setq name (intern name)))
   (setq plain-family-table
         (cons (list name code)
@@ -144,7 +145,7 @@ COMMAND-STRING to the TTS server."
 
 (defun plain-get-family-code (name)
   "Get control code for voice family NAME."
-  (declare (special plain-family-table))
+  (cl-declare (special plain-family-table))
   (when (stringp name)
     (setq name (intern name)))
   (or (cadr (assq  name plain-family-table))
@@ -172,13 +173,13 @@ Values are vectors holding the control codes for the 10 settings.")
   "Set up voice FAMILY.
 Argument DIMENSION is the dimension being set,
 and TABLE gives the values along that dimension."
-  (declare (special plain-css-code-tables))
+  (cl-declare (special plain-css-code-tables))
   (let ((key (intern (format "%s-%s" family dimension))))
     (puthash  key table plain-css-code-tables)))
 
 (defun plain-css-get-code-table (family dimension)
   "Retrieve table of values for specified FAMILY and DIMENSION."
-  (declare (special plain-css-code-tables))
+  (cl-declare (special plain-css-code-tables))
   (let ((key (intern (format "%s-%s" family dimension))))
     (gethash key plain-css-code-tables)))
 
@@ -205,7 +206,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format "") ;no-op -- change to taste
             )))
    '(
@@ -231,7 +232,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format "") ; no-op --- change to taste
             )))
    '(
@@ -256,7 +257,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format ""); no-op --- change to taste
             )))
    '(
@@ -299,7 +300,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format ""); no-op --- chagne to taste.
             )))
    '(
@@ -324,7 +325,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format ""); no-op --- change to taste
             )))
    '(
@@ -349,7 +350,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format ""); no-op --- change to taste
             )))
    '(
@@ -394,7 +395,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format "") ; no-op --- edit to taste
             )))
    '(
@@ -419,7 +420,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format "") ; no-op --- change to taste
             )))
    '(
@@ -444,7 +445,7 @@ and TABLE gives the values along that dimension."
    (function
     (lambda (setting)
       (aset table
-            (first setting)
+            (cl-first setting)
             (format "") ; no-op --- change to taste.
             )))
    '(
@@ -481,7 +482,7 @@ and TABLE gives the values along that dimension."
   (mapcar
    (function
     (lambda (setting)
-      (aset table (first setting)
+      (aset table (cl-first setting)
             (format "") ; no-op --- change to taste
             )))
    '(
@@ -505,7 +506,7 @@ and TABLE gives the values along that dimension."
   (mapcar
    (function
     (lambda (setting)
-      (aset table (first setting)
+      (aset table (cl-first setting)
             (format "") ; no-op --- change to taste
             )))
    '(
@@ -529,7 +530,7 @@ and TABLE gives the values along that dimension."
   (mapcar
    (function
     (lambda (setting)
-      (aset table (first setting)
+      (aset table (cl-first setting)
             (format "") ; no-op -- change to taste.
             )))
    '(
@@ -592,16 +593,16 @@ and TABLE gives the values along that dimension."
 
 (defun plain-list-voices ()
   "List defined voices."
-  (declare (special plain-voice-table))
+  (cl-declare (special plain-voice-table))
   (cl-loop for k being the hash-keys of plain-voice-table
-        collect   k))
+           collect   k))
 
 ;;}}}
 ;;{{{ configurater
 ;;;###autoload
 (defun plain-configure-tts ()
   "Configures TTS environment to use Plain family of synthesizers."
-  (declare (special  plain-default-speech-rate
+  (cl-declare (special  plain-default-speech-rate
                      tts-default-speech-rate
                      tts-default-voice))
   (setq tts-default-voice 'paul)
@@ -618,7 +619,7 @@ and TABLE gives the values along that dimension."
 ;;;###autoload
 (defun plain-make-tts-env  ()
   "Constructs a TTS environment for Plain."
-  (declare (special plain-default-speech-rate))
+  (cl-declare (special plain-default-speech-rate))
   (make-tts-env
    :name :plain :default-voice 'paul
    :default-speech-rate plain-default-speech-rate
@@ -636,7 +637,7 @@ and TABLE gives the values along that dimension."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: nil
+;;; byte-compile-dynamic: t
 ;;; end:
 
 ;;}}}
