@@ -59,8 +59,7 @@
 ;;}}}
 ;;{{{  Required modules
 
-(require 'cl)
-(declaim  (optimize  (safety 0) (speed 3)))
+(require 'cl-lib)
 (require 'derived)
 (require 'ladspa)
 
@@ -103,9 +102,9 @@
      (t
       (cl-loop
        for p in params do
-       (when (second p) (insert (propertize (first p) 'face 'italic))
+       (when (cl-second p) (insert (propertize (cl-first p) 'face 'italic))
              (insert "\t")
-             (insert (propertize (second p) 'face 'bold))
+             (insert (propertize (cl-second p) 'face 'bold))
              (insert "\t")))))
     (put-text-property orig (point) 'sox-effect effect))
   (insert "\n"))
@@ -128,7 +127,7 @@
 (defun sox-refresh ()
   "Redraw Audio Workbench."
   (interactive)
-  (declare (special sox-context))
+  (cl-declare (special sox-context))
   (sox-redraw sox-context))
 
 (defconst sox-header-line-format
@@ -145,7 +144,7 @@
 (define-derived-mode sox-mode special-mode
   "Interactively manipulate audio files."
   "An audio workbench for the Emacspeak desktop."
-  (declare (special sox-context))
+  (cl-declare (special sox-context))
   (setq sox-context (make-sox-context))
   (sox-redraw sox-context)
   (setq buffer-read-only t)
@@ -159,7 +158,7 @@
 (defun sox ()
   "Create a new Audio Workbench or switch to an existing workbench."
   (interactive)
-  (declare (special sox-buffer))
+  (cl-declare (special sox-buffer))
   (unless (get-buffer sox-buffer)
     (let ((buffer (get-buffer-create sox-buffer)))
       (with-current-buffer buffer
@@ -169,7 +168,7 @@
 
 (defun sox-setup-keys ()
   "Set up sox keymap."
-  (declare (special sox-mode-map))
+  (cl-declare (special sox-mode-map))
   (cl-loop
    for k in
    '(
@@ -185,18 +184,18 @@
      ("s" sox-save)
      )
    do
-   (define-key sox-mode-map (kbd (first k)) (second k))))
+   (define-key sox-mode-map (kbd (cl-first k)) (cl-second k))))
 
 ;;}}}
 ;;{{{ Top-level Context:
 
-(defstruct sox-effect
+(cl-defstruct sox-effect
   type ; native: nil ladspa: 'ladspa
   name ; effect name
   params ; list of effect name/value pairs
   )
 
-(defstruct sox-context
+(cl-defstruct sox-context
   file ; file being manipulated
   effects ; list of effects with params
   start-time ; play start time
@@ -218,14 +217,14 @@
 
 (defun sox-sound-p (snd-file)
   "Predicate to test if we can edit this file."
-  (declare (special sox-sound-regexp))
+  (cl-declare (special sox-sound-regexp))
   (let ((case-fold-search t))
     (string-match  sox-sound-regexp snd-file)))
 
 (defun sox-open-file (snd-file)
   "Open specified snd-file on the Audio Workbench."
   (interactive "fSound File: ")
-  (declare (special sox-context))
+  (cl-declare (special sox-context))
   (unless sox-context (error "Audio Workbench not initialized."))
   (let ((inhibit-read-only t)
         (type (sox-sound-p snd-file)))
@@ -251,7 +250,7 @@
        (push (sox-effect-name e) options)
        (cl-loop
         for  p in (sox-effect-params e) do
-        (when (second p)(push (second p)  options))))))
+        (when (cl-second p)(push (cl-second p)  options))))))
     (setq options (nreverse  options))
     (when (string= action sox-edit) (push save-file options))
     (apply #'start-process
@@ -261,7 +260,7 @@
 (defun sox-play ()
   "Play sound from current context."
   (interactive)
-  (declare (special sox-context sox-play))
+  (cl-declare (special sox-context sox-play))
   (when (process-live-p (sox-context-play sox-context))
     (error "Already playing stream."))
   (setf (sox-context-start-time sox-context) (current-time))
@@ -271,7 +270,7 @@
 (defun sox-stop ()
   "Stop currently playing  sound from current context."
   (interactive)
-  (declare (special sox-context))
+  (cl-declare (special sox-context))
   (unless (process-live-p (sox-context-play sox-context))
     (error "Not playing stream."))
   (setf (sox-context-stop-time sox-context) (current-time))
@@ -288,7 +287,7 @@
   (interactive)
   (unless (process-live-p (sox-context-play sox-context))
     (error "Not playing stream."))
-  (declare (special sox-context))
+  (cl-declare (special sox-context))
   (message
    "%.2f"
    (float-time
@@ -297,7 +296,7 @@
 (defun sox-save(save-file)
   "Save context to  file after prompting."
   (interactive "FSave File: ")
-  (declare (special sox-context sox-edit))
+  (cl-declare (special sox-context sox-edit))
   (sox-action sox-context sox-edit save-file))
 (defun sox-edit-effect-at-point ()
   "Edit effect at point."
@@ -322,7 +321,7 @@
 (defun sox-delete-effect-at-point ()
   "Delete effect at point."
   (interactive)
-  (declare (special sox-context))
+  (cl-declare (special sox-context))
   (let ((inhibit-read-only  t)
         (e (sox-effect-at-point)))
     (unless e (error "No effect at point."))
@@ -335,7 +334,7 @@
   "Set effect."
   (interactive
    (list (completing-read "SoX Effect: " sox-effects nil t)))
-  (declare (special sox-context  sox-effects))
+  (cl-declare (special sox-context  sox-effects))
   (setf (sox-context-effects sox-context)
         (list
          (funcall (intern (format  "sox-get-%s-effect"  name)))))
@@ -346,7 +345,7 @@
   "Adds  effect at the end of the effect list"
   (interactive
    (list (completing-read "Add SoX Effect: "  sox-effects nil t)))
-  (declare (special sox-context  sox-effects))
+  (cl-declare (special sox-context  sox-effects))
   (setf (sox-context-effects sox-context)
         (append
          (sox-context-effects sox-context)
@@ -376,9 +375,9 @@
   "Table of implemented effects.")
 
 (defun
- sox-register-effect (name)
+    sox-register-effect (name)
   "Register effect."
-  (pushnew name sox-effects :test #'string=))
+  (cl-pushnew name sox-effects :test #'string=))
 
 ;;; To define support for an effect,:
 ;;; 1. Add it to the effect table below.
@@ -438,7 +437,7 @@ and return a suitable effect structure."
      `(defun ,getter ()
         ,(format "Read needed params for effect %s
 and return a suitable effect structure." name)
-        (declare (special ,p-sym))
+        (cl-declare (special ,p-sym))
         (make-sox-effect
          :name ,name
          :params (sox-read-effect-params ,p-sym ,repeat))))))
@@ -483,6 +482,7 @@ and return a suitable effect structure." name)
 ;;{{{ Add Emacspeak Support
 
 ;;; Code here can be factored out to emacspeak-sox.el
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 
 (defadvice sox-open-file(after emacspeak pre act comp)
