@@ -1,16 +1,13 @@
-;; -*- lexical-binding: t; -*-
-(augment-load-path "jabber")
-(load-library "jabber-autoloads")
+;; -*- lexical-binding: nil; -*-
+
+;(load-library "jabber-autoloads")
 (setq fsm-debug nil)
 (add-hook 'jabber-roster-mode-hook
           #'(lambda nil
-              (setq buffer-undo-list t)))
-
-;;; terse modeline
-(require 'jabber-modeline)
-(setq jabber-mode-line-string
+              (setq jabber-mode-line-string
       (list " "
               'jabber-mode-line-presence
               ;" "
               ;'jabber-mode-line-contacts
               ))
+              (setq buffer-undo-list t)))
