@@ -1,9 +1,10 @@
-;; -*- lexical-binding: t; -*-
-(require 'epa)
-(augment-load-path "twittering-mode" "twittering-mode")
-(load-library "twittering-mode")
+;; -*- lexical-binding: nil; -*-
+
 (setq twittering-use-master-password t)
 (setq epa-protocol 'OpenPGP)
+(eval-after-load "twittering-mode"
+`(progn
+   (require 'epa)
 (setq twittering-timer-interval 300)
 (setq twittering-timer-interval-for-redisplaying 300)
 (setq twittering-initial-timeline-spec-string
@@ -12,3 +13,4 @@
                 ))
 (setq twittering-number-of-tweets-on-retrieval 50)
 (setq twittering-edit-skeleton 'inherit-any)
+))
